@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2025 OpenRCT2 developers
+ * Copyright (c) 2014-2026 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -114,7 +114,7 @@ namespace OpenRCT2::Ui
             case ViewportInteractionItem::entity:
                 switch (sprite->Type)
                 {
-                    case EntityType::Vehicle:
+                    case EntityType::vehicle:
                     {
                         auto vehicle = sprite->As<Vehicle>();
                         if (vehicle != nullptr && !vehicle->IsCableLift())
@@ -123,8 +123,8 @@ namespace OpenRCT2::Ui
                             info.interactionType = ViewportInteractionItem::none;
                     }
                     break;
-                    case EntityType::Guest:
-                    case EntityType::Staff:
+                    case EntityType::guest:
+                    case EntityType::staff:
                     {
                         auto peep = sprite->As<Peep>();
                         if (peep != nullptr)
@@ -205,22 +205,22 @@ namespace OpenRCT2::Ui
                 auto entity = info.Entity;
                 switch (entity->Type)
                 {
-                    case EntityType::Vehicle:
+                    case EntityType::vehicle:
                     {
                         auto intent = Intent(WindowDetail::vehicle);
                         intent.PutExtra(INTENT_EXTRA_VEHICLE, entity);
                         ContextOpenIntent(&intent);
                         break;
                     }
-                    case EntityType::Guest:
-                    case EntityType::Staff:
+                    case EntityType::guest:
+                    case EntityType::staff:
                     {
                         auto intent = Intent(WindowClass::peep);
                         intent.PutExtra(INTENT_EXTRA_PEEP, entity);
                         ContextOpenIntent(&intent);
                         break;
                     }
-                    case EntityType::Balloon:
+                    case EntityType::balloon:
                     {
                         if (GameIsNotPaused())
                         {
@@ -229,7 +229,7 @@ namespace OpenRCT2::Ui
                         }
                     }
                     break;
-                    case EntityType::Duck:
+                    case EntityType::duck:
                     {
                         if (GameIsNotPaused())
                         {
@@ -268,7 +268,6 @@ namespace OpenRCT2::Ui
     static InteractionInfo ViewportInteractionGetItemRight(const ScreenCoordsXY& screenCoords)
     {
         Ride* ride;
-        int32_t i;
         InteractionInfo info{};
         // No click input for title screen or track manager
         if (gLegacyScene == LegacyScene::titleSequence || gLegacyScene == LegacyScene::trackDesignsManager)
@@ -288,7 +287,7 @@ namespace OpenRCT2::Ui
             case ViewportInteractionItem::entity:
             {
                 auto sprite = info.Entity;
-                if (gLegacyScene == LegacyScene::scenarioEditor || sprite->Type != EntityType::Vehicle)
+                if (gLegacyScene == LegacyScene::scenarioEditor || sprite->Type != EntityType::vehicle)
                 {
                     info.interactionType = ViewportInteractionItem::none;
                     return info;
@@ -400,7 +399,7 @@ namespace OpenRCT2::Ui
                 else
                     stationIndex = tileElement->AsTrack()->GetStationIndex().ToUnderlying();
 
-                for (i = stationIndex; i >= 0; i--)
+                for (int32_t i = stationIndex; i >= 0; i--)
                     if (ride->getStations()[i].Start.IsNull())
                         stationIndex--;
                 stationIndex++;
@@ -467,7 +466,7 @@ namespace OpenRCT2::Ui
                 break;
         }
 
-        if (!gInputFlags.has(InputFlag::unk6) || !gInputFlags.has(InputFlag::toolActive))
+        if (!gInputFlags.has(InputFlag::allowRightMouseRemoval) || !gInputFlags.has(InputFlag::toolActive))
         {
             auto* windowMgr = GetWindowManager();
             if (windowMgr->FindByClass(WindowClass::rideConstruction) == nullptr
@@ -573,7 +572,7 @@ namespace OpenRCT2::Ui
             case ViewportInteractionItem::entity:
             {
                 auto entity = info.Entity;
-                if (entity->Type == EntityType::Vehicle)
+                if (entity->Type == EntityType::vehicle)
                 {
                     auto vehicle = entity->As<Vehicle>();
                     if (vehicle == nullptr)
