@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2025 OpenRCT2 developers
+ * Copyright (c) 2014-2026 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -16,6 +16,10 @@
 #include <openrct2/Input.h>
 #include <openrct2/OpenRCT2.h>
 #include <openrct2/SpriteIds.h>
+#include <openrct2/drawing/ColourMap.h>
+#include <openrct2/drawing/Drawing.h>
+#include <openrct2/drawing/Rectangle.h>
+#include <openrct2/interface/ColourWithFlags.h>
 #include <openrct2/interface/Cursors.h>
 #include <openrct2/localisation/Formatter.h>
 #include <openrct2/management/Research.h>
@@ -28,6 +32,8 @@
 #include <openrct2/ui/WindowManager.h>
 #include <openrct2/world/Scenery.h>
 
+using namespace OpenRCT2::Drawing;
+
 namespace OpenRCT2::Ui::Windows
 {
 #pragma region Widgets
@@ -107,11 +113,10 @@ namespace OpenRCT2::Ui::Windows
         const StringId itemNameId = researchItem.GetName();
         int16_t columnSplitOffset = width / 2;
 
-        if (researchItem.type == Research::EntryType::Ride
+        if (researchItem.type == Research::EntryType::ride
             && !GetRideTypeDescriptor(researchItem.baseRideType).HasFlag(RtdFlag::listVehiclesSeparately))
         {
-            const StringId rideTypeName = GetRideNaming(
-                                              researchItem.baseRideType, *GetRideEntryByIndex(researchItem.entryIndex))
+            const StringId rideTypeName = GetRideNaming(researchItem.baseRideType, GetRideEntryByIndex(researchItem.entryIndex))
                                               .Name;
 
             // Draw group name
@@ -271,10 +276,10 @@ namespace OpenRCT2::Ui::Windows
             const auto& gameState = getGameState();
 
             // Draw background
-            uint8_t paletteIndex = ColourMapA[colours[1].colour].mid_light;
+            auto paletteIndex = getColourMap(colours[1].colour).midLight;
             GfxClear(rt, paletteIndex);
 
-            int16_t boxWidth = widgets[WIDX_RESEARCH_ORDER_SCROLL].width();
+            int16_t boxWidth = widgets[WIDX_RESEARCH_ORDER_SCROLL].width() - 1;
             int32_t itemY = -kScrollableRowHeight;
             auto* dragItem = WindowEditorInventionsListDragGetItem();
 
@@ -301,7 +306,7 @@ namespace OpenRCT2::Ui::Windows
                         bottom = itemY;
                     }
 
-                    GfxFilterRect(rt, { 0, top, boxWidth, bottom }, FilterPaletteID::paletteDarken1);
+                    Rectangle::filter(rt, { 0, top, boxWidth, bottom }, FilterPaletteID::paletteDarken1);
                 }
 
                 if (dragItem != nullptr && researchItem == *dragItem)
@@ -309,16 +314,16 @@ namespace OpenRCT2::Ui::Windows
 
                 // TODO: this parameter by itself produces very light text.
                 // It needs a {BLACK} token in the string to work properly.
-                ColourWithFlags colour = { COLOUR_BLACK };
-                FontStyle fontStyle = FontStyle::Medium;
-                auto darkness = TextDarkness::Regular;
+                ColourWithFlags colour = { Drawing::Colour::black };
+                FontStyle fontStyle = FontStyle::medium;
+                auto darkness = TextDarkness::regular;
 
                 if (researchItem.IsAlwaysResearched())
                 {
                     if (_selectedResearchItem == &researchItem && dragItem == nullptr)
-                        darkness = TextDarkness::ExtraDark;
+                        darkness = TextDarkness::extraDark;
                     else
-                        darkness = TextDarkness::Dark;
+                        darkness = TextDarkness::dark;
                     colour = colours[1].withFlag(ColourFlag::inset, true);
                 }
 
@@ -371,11 +376,11 @@ namespace OpenRCT2::Ui::Windows
 
             // Preview background
             auto& bkWidget = widgets[WIDX_PREVIEW];
-            GfxFillRect(
+            Rectangle::fill(
                 rt,
                 { windowPos + ScreenCoordsXY{ bkWidget.left + 1, bkWidget.top + 1 },
                   windowPos + ScreenCoordsXY{ bkWidget.right - 1, bkWidget.bottom - 1 } },
-                ColourMapA[colours[1].colour].darkest);
+                getColourMap(colours[1].colour).darkest);
 
             auto* researchItem = WindowEditorInventionsListDragGetItem();
             if (researchItem == nullptr || researchItem->IsNull())
@@ -386,7 +391,7 @@ namespace OpenRCT2::Ui::Windows
 
             // Preview image
             ObjectType objectEntryType = ObjectType::sceneryGroup;
-            if (researchItem->type == Research::EntryType::Ride)
+            if (researchItem->type == Research::EntryType::ride)
                 objectEntryType = ObjectType::ride;
 
             auto chunk = ObjectEntryGetChunk(objectEntryType, researchItem->entryIndex);
@@ -397,13 +402,13 @@ namespace OpenRCT2::Ui::Windows
             const auto* object = ObjectEntryGetObject(objectEntryType, researchItem->entryIndex);
             if (object != nullptr)
             {
-                RenderTarget clipDPI;
+                RenderTarget clipRT;
                 screenPos = windowPos + ScreenCoordsXY{ bkWidget.left + 1, bkWidget.top + 1 };
-                const auto clipWidth = bkWidget.width() - 1;
-                const auto clipHeight = bkWidget.height() - 1;
-                if (ClipDrawPixelInfo(clipDPI, rt, screenPos, clipWidth, clipHeight))
+                const auto clipWidth = bkWidget.width() - 2;
+                const auto clipHeight = bkWidget.height() - 2;
+                if (ClipRenderTarget(clipRT, rt, screenPos, clipWidth, clipHeight))
                 {
-                    object->DrawPreview(clipDPI, clipWidth, clipHeight);
+                    object->DrawPreview(clipRT, clipWidth, clipHeight);
                 }
             }
 
@@ -415,12 +420,11 @@ namespace OpenRCT2::Ui::Windows
             StringId stringId = researchItem->GetName();
             auto ft = Formatter();
 
-            if (researchItem->type == Research::EntryType::Ride
+            if (researchItem->type == Research::EntryType::ride
                 && !GetRideTypeDescriptor(researchItem->baseRideType).HasFlag(RtdFlag::listVehiclesSeparately))
             {
                 drawString = STR_WINDOW_COLOUR_2_STRINGID_STRINGID;
-                StringId rideTypeName = GetRideNaming(
-                                            researchItem->baseRideType, *GetRideEntryByIndex(researchItem->entryIndex))
+                StringId rideTypeName = GetRideNaming(researchItem->baseRideType, GetRideEntryByIndex(researchItem->entryIndex))
                                             .Name;
                 ft.Add<StringId>(rideTypeName);
                 ft.Add<StringId>(stringId);
@@ -430,7 +434,7 @@ namespace OpenRCT2::Ui::Windows
                 ft.Add<StringId>(stringId);
             }
 
-            DrawTextEllipsised(rt, screenPos, itemWidth, drawString, ft, { TextAlignment::CENTRE });
+            DrawTextEllipsised(rt, screenPos, itemWidth, drawString, ft, { TextAlignment::centre });
             screenPos.y += 15;
 
             // Item category
@@ -603,7 +607,7 @@ namespace OpenRCT2::Ui::Windows
         void onOpen() override
         {
             setWidgets(_inventionListDragWidgets);
-            colours[1] = COLOUR_WHITE;
+            colours[1] = Drawing::Colour::white;
         }
 
         CursorID onCursor(const WidgetIndex widx, const ScreenCoordsXY& screenCoords, const CursorID defaultCursor) override
@@ -659,7 +663,7 @@ namespace OpenRCT2::Ui::Windows
 
             DrawResearchItem(
                 rt, _draggedItem, width, screenCoords, STR_WINDOW_COLOUR_2_STRINGID,
-                { ColourWithFlags{ COLOUR_BLACK }.withFlag(ColourFlag::withOutline, true) });
+                { ColourWithFlags{ Drawing::Colour::black }.withFlag(ColourFlag::withOutline, true) });
         }
 
         void init(ResearchItem& researchItem, const ScreenCoordsXY& editorPos, int objectSelectionScrollWidth)
@@ -684,7 +688,7 @@ namespace OpenRCT2::Ui::Windows
     static void WindowEditorInventionsListDragOpen(
         ResearchItem* researchItem, const ScreenCoordsXY& editorPos, int objectSelectionScrollWidth)
     {
-        auto* windowMgr = Ui::GetWindowManager();
+        auto* windowMgr = GetWindowManager();
         windowMgr->CloseByClass(WindowClass::editorInventionListDrag);
         auto* wnd = windowMgr->Create<InventionDragWindow>(
             WindowClass::editorInventionListDrag, { 10, 14 },
