@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2025 OpenRCT2 developers
+ * Copyright (c) 2014-2026 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -29,8 +29,11 @@
 #include <openrct2/object/TerrainEdgeObject.h>
 #include <openrct2/object/TerrainSurfaceObject.h>
 #include <openrct2/ui/WindowManager.h>
+#include <openrct2/world/MapSelection.h>
 #include <openrct2/world/Park.h>
 
+using OpenRCT2::GameActions::CommandFlag;
+
 namespace OpenRCT2::Ui::Windows
 {
     static constexpr StringId kWindowTitle = STR_LAND;
@@ -50,6 +53,12 @@ namespace OpenRCT2::Ui::Windows
         WIDX_WALL,
     };
 
+    enum class SelectionMode
+    {
+        query,
+        apply,
+    };
+
     // clang-format off
     static constexpr auto window_land_widgets = makeWidgets(
         makeWindowShim(kWindowTitle, kWindowSize),
@@ -86,11 +95,11 @@ namespace OpenRCT2::Ui::Windows
         }
 
     public:
-        void OnOpen() override
+        void onOpen() override
         {
-            SetWidgets(window_land_widgets);
+            setWidgets(window_land_widgets);
 
-            hold_down_widgets = (1uLL << WIDX_DECREMENT) | (1uLL << WIDX_INCREMENT);
+            holdDownWidgets = (1uLL << WIDX_DECREMENT) | (1uLL << WIDX_INCREMENT);
             WindowInitScrollWidgets(*this);
             WindowPushOthersBelow(*this);
 
@@ -102,29 +111,29 @@ namespace OpenRCT2::Ui::Windows
             _selectedWallTexture = LandTool::GetEdgeStyleFromDropdownIndex(0);
         }
 
-        void OnClose() override
+        void onClose() override
         {
             // If the tool wasn't changed, turn tool off
-            if (isToolActive(WindowClass::Land, WIDX_BACKGROUND))
+            if (isToolActive(WindowClass::land, WIDX_BACKGROUND))
                 ToolCancel();
         }
 
-        void OnMouseUp(WidgetIndex widgetIndex) override
+        void onMouseUp(WidgetIndex widgetIndex) override
         {
             switch (widgetIndex)
             {
                 case WIDX_CLOSE:
-                    Close();
+                    close();
                     break;
                 case WIDX_MOUNTAINMODE:
                     _landToolMountainMode ^= 1;
-                    _landToolPaintMode = 0;
-                    Invalidate();
+                    _landToolPaintMode = false;
+                    invalidate();
                     break;
                 case WIDX_PAINTMODE:
-                    _landToolMountainMode = 0;
+                    _landToolMountainMode = false;
                     _landToolPaintMode ^= 1;
-                    Invalidate();
+                    invalidate();
                     break;
                 case WIDX_PREVIEW:
                     InputSize();
@@ -132,7 +141,7 @@ namespace OpenRCT2::Ui::Windows
             }
         }
 
-        void OnMouseDown(WidgetIndex widgetIndex) override
+        void onMouseDown(WidgetIndex widgetIndex) override
         {
             Widget* widget = &widgets[widgetIndex];
             switch (widgetIndex)
@@ -151,19 +160,19 @@ namespace OpenRCT2::Ui::Windows
                     gLandToolSize = std::max<uint16_t>(kLandToolMinimumSize, gLandToolSize - 1);
 
                     // Invalidate the window
-                    Invalidate();
+                    invalidate();
                     break;
                 case WIDX_INCREMENT:
                     // Increment land tool size
                     gLandToolSize = std::min<uint16_t>(kLandToolMaximumSize, gLandToolSize + 1);
 
                     // Invalidate the window
-                    Invalidate();
+                    invalidate();
                     break;
             }
         }
 
-        void OnDropdown(WidgetIndex widgetIndex, int32_t dropdownIndex) override
+        void onDropdown(WidgetIndex widgetIndex, int32_t dropdownIndex) override
         {
             int32_t type;
 
@@ -186,7 +195,7 @@ namespace OpenRCT2::Ui::Windows
                         gLandToolTerrainSurface = type;
                         _selectedFloorTexture = type;
                     }
-                    Invalidate();
+                    invalidate();
                     break;
                 case WIDX_WALL:
                     if (dropdownIndex == -1)
@@ -204,12 +213,12 @@ namespace OpenRCT2::Ui::Windows
                         gLandToolTerrainEdge = type;
                         _selectedWallTexture = type;
                     }
-                    Invalidate();
+                    invalidate();
                     break;
             }
         }
 
-        void OnTextInput(WidgetIndex widgetIndex, std::string_view text) override
+        void onTextInput(WidgetIndex widgetIndex, std::string_view text) override
         {
             if (widgetIndex != WIDX_PREVIEW)
                 return;
@@ -223,41 +232,41 @@ namespace OpenRCT2::Ui::Windows
                 size = std::min<uint16_t>(kLandToolMaximumSize, size);
                 gLandToolSize = size;
 
-                Invalidate();
+                invalidate();
             }
         }
 
-        void OnUpdate() override
+        void onUpdate() override
         {
-            if (!isToolActive(WindowClass::Land, WIDX_BACKGROUND))
-                Close();
+            if (!isToolActive(WindowClass::land, WIDX_BACKGROUND))
+                close();
         }
 
-        void OnPrepareDraw() override
+        void onPrepareDraw() override
         {
-            pressed_widgets = 0;
-            SetWidgetPressed(WIDX_PREVIEW, true);
+            pressedWidgets = 0;
+            setWidgetPressed(WIDX_PREVIEW, true);
             if (gLandToolTerrainSurface != kObjectEntryIndexNull)
-                SetWidgetPressed(WIDX_FLOOR, true);
+                setWidgetPressed(WIDX_FLOOR, true);
             if (gLandToolTerrainEdge != kObjectEntryIndexNull)
-                SetWidgetPressed(WIDX_WALL, true);
+                setWidgetPressed(WIDX_WALL, true);
             if (_landToolMountainMode)
-                SetWidgetPressed(WIDX_MOUNTAINMODE, true);
+                setWidgetPressed(WIDX_MOUNTAINMODE, true);
             if (_landToolPaintMode)
-                SetWidgetPressed(WIDX_PAINTMODE, true);
+                setWidgetPressed(WIDX_PAINTMODE, true);
 
             // Update the preview image (for tool sizes up to 7)
             widgets[WIDX_PREVIEW].image = ImageId(LandTool::SizeToSpriteIndex(gLandToolSize));
         }
 
-        void OnDraw(RenderTarget& rt) override
+        void onDraw(Drawing::RenderTarget& rt) override
         {
             ScreenCoordsXY screenCoords;
             int32_t numTiles;
             money64 price;
             Widget* previewWidget = &widgets[WIDX_PREVIEW];
 
-            DrawWidgets(rt);
+            drawWidgets(rt);
             DrawDropdownButtons(rt);
 
             // Draw number for tool sizes bigger than 7
@@ -267,7 +276,7 @@ namespace OpenRCT2::Ui::Windows
                 ft.Add<uint16_t>(gLandToolSize);
                 screenCoords = { windowPos.x + previewWidget->midX(), windowPos.y + previewWidget->midY() };
                 DrawTextBasic(
-                    rt, screenCoords - ScreenCoordsXY{ 0, 2 }, STR_LAND_TOOL_SIZE_VALUE, ft, { TextAlignment::CENTRE });
+                    rt, screenCoords - ScreenCoordsXY{ 0, 2 }, STR_LAND_TOOL_SIZE_VALUE, ft, { TextAlignment::centre });
             }
             else if (_landToolMountainMode)
             {
@@ -287,7 +296,7 @@ namespace OpenRCT2::Ui::Windows
                 {
                     auto ft = Formatter();
                     ft.Add<money64>(_landToolRaiseCost);
-                    DrawTextBasic(rt, screenCoords, STR_RAISE_COST_AMOUNT, ft, { TextAlignment::CENTRE });
+                    DrawTextBasic(rt, screenCoords, STR_RAISE_COST_AMOUNT, ft, { TextAlignment::centre });
                 }
                 screenCoords.y += 10;
 
@@ -296,7 +305,7 @@ namespace OpenRCT2::Ui::Windows
                 {
                     auto ft = Formatter();
                     ft.Add<money64>(_landToolLowerCost);
-                    DrawTextBasic(rt, screenCoords, STR_LOWER_COST_AMOUNT, ft, { TextAlignment::CENTRE });
+                    DrawTextBasic(rt, screenCoords, STR_LOWER_COST_AMOUNT, ft, { TextAlignment::centre });
                 }
                 screenCoords.y += 50;
 
@@ -320,72 +329,83 @@ namespace OpenRCT2::Ui::Windows
                 {
                     auto ft = Formatter();
                     ft.Add<money64>(price);
-                    DrawTextBasic(rt, screenCoords, STR_COST_AMOUNT, ft, { TextAlignment::CENTRE });
+                    DrawTextBasic(rt, screenCoords, STR_COST_AMOUNT, ft, { TextAlignment::centre });
                 }
             }
         }
 
     private:
+        static money64 executeGameAction(GameState_t& gameState, GameActions::GameAction* action, SelectionMode mode)
+        {
+            GameActions::Result res;
+            if (mode == SelectionMode::apply)
+            {
+                res = GameActions::Execute(action, gameState);
+            }
+            else
+            {
+                action->SetFlags({ CommandFlag::allowDuringPaused });
+                res = GameActions::Query(action, gameState);
+            }
+            return res.error == GameActions::Status::ok ? res.cost : kMoney64Undefined;
+        }
+
         /**
          *
          *  rct2: 0x006644DD
          */
-        money64 SelectionRaiseLand(uint8_t flag)
+        money64 SelectionRaiseLand(const SelectionMode mode)
         {
             int32_t centreX = (gMapSelectPositionA.x + gMapSelectPositionB.x) / 2;
             int32_t centreY = (gMapSelectPositionA.y + gMapSelectPositionB.y) / 2;
             centreX += 16;
             centreY += 16;
 
+            auto& gameState = getGameState();
+
             if (_landToolMountainMode)
             {
                 auto landSmoothAction = GameActions::LandSmoothAction(
                     { centreX, centreY },
                     { gMapSelectPositionA.x, gMapSelectPositionA.y, gMapSelectPositionB.x, gMapSelectPositionB.y },
                     gMapSelectType, false);
-                auto res = (flag & GAME_COMMAND_FLAG_APPLY) ? GameActions::Execute(&landSmoothAction)
-                                                            : GameActions::Query(&landSmoothAction);
-                return res.Error == GameActions::Status::Ok ? res.Cost : kMoney64Undefined;
+                return executeGameAction(gameState, &landSmoothAction, mode);
             }
 
             auto landRaiseAction = GameActions::LandRaiseAction(
                 { centreX, centreY },
                 { gMapSelectPositionA.x, gMapSelectPositionA.y, gMapSelectPositionB.x, gMapSelectPositionB.y }, gMapSelectType);
-            auto res = (flag & GAME_COMMAND_FLAG_APPLY) ? GameActions::Execute(&landRaiseAction)
-                                                        : GameActions::Query(&landRaiseAction);
 
-            return res.Error == GameActions::Status::Ok ? res.Cost : kMoney64Undefined;
+            return executeGameAction(gameState, &landRaiseAction, mode);
         }
 
         /**
          *
          *  rct2: 0x006645B3
          */
-        money64 SelectionLowerLand(uint8_t flag)
+        money64 SelectionLowerLand(const SelectionMode mode)
         {
             int32_t centreX = (gMapSelectPositionA.x + gMapSelectPositionB.x) / 2;
             int32_t centreY = (gMapSelectPositionA.y + gMapSelectPositionB.y) / 2;
             centreX += 16;
             centreY += 16;
 
+            auto& gameState = getGameState();
+
             if (_landToolMountainMode)
             {
                 auto landSmoothAction = GameActions::LandSmoothAction(
                     { centreX, centreY },
                     { gMapSelectPositionA.x, gMapSelectPositionA.y, gMapSelectPositionB.x, gMapSelectPositionB.y },
                     gMapSelectType, true);
-                auto res = (flag & GAME_COMMAND_FLAG_APPLY) ? GameActions::Execute(&landSmoothAction)
-                                                            : GameActions::Query(&landSmoothAction);
-                return res.Error == GameActions::Status::Ok ? res.Cost : kMoney64Undefined;
+                return executeGameAction(gameState, &landSmoothAction, mode);
             }
 
             auto landLowerAction = GameActions::LandLowerAction(
                 { centreX, centreY },
                 { gMapSelectPositionA.x, gMapSelectPositionA.y, gMapSelectPositionB.x, gMapSelectPositionB.y }, gMapSelectType);
-            auto res = (flag & GAME_COMMAND_FLAG_APPLY) ? GameActions::Execute(&landLowerAction)
-                                                        : GameActions::Query(&landLowerAction);
 
-            return res.Error == GameActions::Status::Ok ? res.Cost : kMoney64Undefined;
+            return executeGameAction(gameState, &landLowerAction, mode);
         }
 
         /**
@@ -419,7 +439,7 @@ namespace OpenRCT2::Ui::Windows
             {
                 gInputDragLast.y += tile_height;
 
-                SelectionRaiseLand(GAME_COMMAND_FLAG_APPLY);
+                SelectionRaiseLand(SelectionMode::apply);
 
                 _landToolRaiseCost = kMoney64Undefined;
                 _landToolLowerCost = kMoney64Undefined;
@@ -428,7 +448,7 @@ namespace OpenRCT2::Ui::Windows
             {
                 gInputDragLast.y -= tile_height;
 
-                SelectionLowerLand(GAME_COMMAND_FLAG_APPLY);
+                SelectionLowerLand(SelectionMode::apply);
 
                 _landToolRaiseCost = kMoney64Undefined;
                 _landToolLowerCost = kMoney64Undefined;
@@ -439,8 +459,7 @@ namespace OpenRCT2::Ui::Windows
         {
             uint8_t state_changed = 0;
 
-            MapInvalidateSelectionRect();
-            gMapSelectFlags &= ~MAP_SELECT_FLAG_ENABLE;
+            gMapSelectFlags.unset(MapSelectFlag::enable);
 
             auto mapTile = ScreenGetMapXY(screenPos, nullptr);
 
@@ -449,15 +468,15 @@ namespace OpenRCT2::Ui::Windows
                 return state_changed;
             }
 
-            if (!(gMapSelectFlags & MAP_SELECT_FLAG_ENABLE))
+            if (!gMapSelectFlags.has(MapSelectFlag::enable))
             {
-                gMapSelectFlags |= MAP_SELECT_FLAG_ENABLE;
+                gMapSelectFlags.set(MapSelectFlag::enable);
                 state_changed++;
             }
 
-            if (gMapSelectType != MAP_SELECT_TYPE_FULL)
+            if (gMapSelectType != MapSelectType::full)
             {
-                gMapSelectType = MAP_SELECT_TYPE_FULL;
+                gMapSelectType = MapSelectType::full;
                 state_changed++;
             }
 
@@ -496,12 +515,11 @@ namespace OpenRCT2::Ui::Windows
                 state_changed++;
             }
 
-            MapInvalidateSelectionRect();
             return state_changed;
         }
 
     public:
-        void OnToolUpdate(WidgetIndex widgetIndex, const ScreenCoordsXY& screenCoords) override
+        void onToolUpdate(WidgetIndex widgetIndex, const ScreenCoordsXY& screenCoords) override
         {
             switch (widgetIndex)
             {
@@ -514,18 +532,18 @@ namespace OpenRCT2::Ui::Windows
             }
         }
 
-        void OnToolDown(WidgetIndex widgetIndex, const ScreenCoordsXY& screenCoords) override
+        void onToolDown(WidgetIndex widgetIndex, const ScreenCoordsXY& screenCoords) override
         {
             switch (widgetIndex)
             {
                 case WIDX_BACKGROUND:
-                    if (gMapSelectFlags & MAP_SELECT_FLAG_ENABLE)
+                    if (gMapSelectFlags.has(MapSelectFlag::enable))
                     {
                         auto surfaceSetStyleAction = GameActions::SurfaceSetStyleAction(
                             { gMapSelectPositionA.x, gMapSelectPositionA.y, gMapSelectPositionB.x, gMapSelectPositionB.y },
                             gLandToolTerrainSurface, gLandToolTerrainEdge);
 
-                        GameActions::Execute(&surfaceSetStyleAction);
+                        GameActions::Execute(&surfaceSetStyleAction, getGameState());
 
                         gCurrentToolId = Tool::upDownArrow;
                     }
@@ -537,7 +555,7 @@ namespace OpenRCT2::Ui::Windows
             }
         }
 
-        void OnToolDrag(WidgetIndex widgetIndex, const ScreenCoordsXY& screenCoords) override
+        void onToolDrag(WidgetIndex widgetIndex, const ScreenCoordsXY& screenCoords) override
         {
             switch (widgetIndex)
             {
@@ -546,13 +564,13 @@ namespace OpenRCT2::Ui::Windows
                     // Custom setting to only change land style instead of raising or lowering land
                     if (_landToolPaintMode)
                     {
-                        if (gMapSelectFlags & MAP_SELECT_FLAG_ENABLE)
+                        if (gMapSelectFlags.has(MapSelectFlag::enable))
                         {
                             auto surfaceSetStyleAction = GameActions::SurfaceSetStyleAction(
                                 { gMapSelectPositionA.x, gMapSelectPositionA.y, gMapSelectPositionB.x, gMapSelectPositionB.y },
                                 gLandToolTerrainSurface, gLandToolTerrainEdge);
 
-                            GameActions::Execute(&surfaceSetStyleAction);
+                            GameActions::Execute(&surfaceSetStyleAction, getGameState());
 
                             // The tool is set to 12 here instead of 3 so that the dragging cursor is not the elevation change
                             // cursor
@@ -571,20 +589,19 @@ namespace OpenRCT2::Ui::Windows
             }
         }
 
-        void OnToolUp(WidgetIndex widgetIndex, const ScreenCoordsXY& screenCoords) override
+        void onToolUp(WidgetIndex widgetIndex, const ScreenCoordsXY& screenCoords) override
         {
             _landToolBlocked = false;
             switch (widgetIndex)
             {
                 case WIDX_BACKGROUND:
-                    MapInvalidateSelectionRect();
-                    gMapSelectFlags &= ~MAP_SELECT_FLAG_ENABLE;
+                    gMapSelectFlags.unset(MapSelectFlag::enable);
                     gCurrentToolId = Tool::digDown;
                     break;
             }
         }
 
-        void OnToolAbort(WidgetIndex widgetIndex) override
+        void onToolAbort(WidgetIndex widgetIndex) override
         {
             switch (widgetIndex)
             {
@@ -601,24 +618,22 @@ namespace OpenRCT2::Ui::Windows
          */
         void ToolUpdateLand(const ScreenCoordsXY& screenPos)
         {
-            const bool mapCtrlPressed = GetInputManager().IsModifierKeyPressed(ModifierKey::ctrl);
-            auto* windowMgr = Ui::GetWindowManager();
-
-            MapInvalidateSelectionRect();
+            const bool mapCtrlPressed = GetInputManager().isModifierKeyPressed(ModifierKey::ctrl);
+            auto* windowMgr = GetWindowManager();
 
             if (gCurrentToolId == Tool::upDownArrow)
             {
-                if (!(gMapSelectFlags & MAP_SELECT_FLAG_ENABLE))
+                if (!gMapSelectFlags.has(MapSelectFlag::enable))
                     return;
 
-                money64 lower_cost = SelectionLowerLand(0);
-                money64 raise_cost = SelectionRaiseLand(0);
+                money64 lower_cost = SelectionLowerLand(SelectionMode::query);
+                money64 raise_cost = SelectionRaiseLand(SelectionMode::query);
 
                 if (_landToolRaiseCost != raise_cost || _landToolLowerCost != lower_cost)
                 {
                     _landToolRaiseCost = raise_cost;
                     _landToolLowerCost = lower_cost;
-                    windowMgr->InvalidateByClass(WindowClass::Land);
+                    windowMgr->InvalidateByClass(WindowClass::land);
                 }
                 return;
             }
@@ -627,12 +642,13 @@ namespace OpenRCT2::Ui::Windows
             std::optional<CoordsXY> mapTile;
             uint8_t side{};
 
-            gMapSelectFlags &= ~MAP_SELECT_FLAG_ENABLE;
+            gMapSelectFlags.unset(MapSelectFlag::enable);
             if (tool_size == 1)
             {
-                int32_t selectionType;
+                int32_t direction;
                 // Get selection type and map coordinates from mouse x,y position
-                ScreenPosToMapPos(screenPos, &selectionType);
+                ScreenPosToMapPos(screenPos, &direction);
+                MapSelectType selectionType = static_cast<MapSelectType>(direction);
                 mapTile = ScreenGetMapXYSide(screenPos, &side);
 
                 if (!mapTile.has_value())
@@ -644,16 +660,16 @@ namespace OpenRCT2::Ui::Windows
                     {
                         _landToolRaiseCost = raise_cost;
                         _landToolLowerCost = lower_cost;
-                        windowMgr->InvalidateByClass(WindowClass::Land);
+                        windowMgr->InvalidateByClass(WindowClass::land);
                     }
                     return;
                 }
 
                 uint8_t state_changed = 0;
 
-                if (!(gMapSelectFlags & MAP_SELECT_FLAG_ENABLE))
+                if (!gMapSelectFlags.has(MapSelectFlag::enable))
                 {
-                    gMapSelectFlags |= MAP_SELECT_FLAG_ENABLE;
+                    gMapSelectFlags.set(MapSelectFlag::enable);
                     state_changed++;
                 }
 
@@ -663,9 +679,10 @@ namespace OpenRCT2::Ui::Windows
                     state_changed++;
                 }
 
-                if ((gMapSelectType != MAP_SELECT_TYPE_EDGE_0 + (side & 0xFF)) && mapCtrlPressed)
+                MapSelectType selectedSide = getMapSelectEdge(side & 0xFF);
+                if (gMapSelectType != selectedSide && mapCtrlPressed)
                 {
-                    gMapSelectType = MAP_SELECT_TYPE_EDGE_0 + (side & 0xFF);
+                    gMapSelectType = selectedSide;
                     state_changed++;
                 }
 
@@ -693,18 +710,17 @@ namespace OpenRCT2::Ui::Windows
                     state_changed++;
                 }
 
-                MapInvalidateSelectionRect();
                 if (!state_changed)
                     return;
 
-                money64 lower_cost = SelectionLowerLand(0);
-                money64 raise_cost = SelectionRaiseLand(0);
+                money64 lower_cost = SelectionLowerLand(SelectionMode::query);
+                money64 raise_cost = SelectionRaiseLand(SelectionMode::query);
 
                 if (_landToolRaiseCost != raise_cost || _landToolLowerCost != lower_cost)
                 {
                     _landToolRaiseCost = raise_cost;
                     _landToolLowerCost = lower_cost;
-                    windowMgr->InvalidateByClass(WindowClass::Land);
+                    windowMgr->InvalidateByClass(WindowClass::land);
                 }
                 return;
             }
@@ -721,28 +737,29 @@ namespace OpenRCT2::Ui::Windows
                 {
                     _landToolRaiseCost = raise_cost;
                     _landToolLowerCost = lower_cost;
-                    windowMgr->InvalidateByClass(WindowClass::Land);
+                    windowMgr->InvalidateByClass(WindowClass::land);
                 }
                 return;
             }
 
             uint8_t state_changed = 0;
 
-            if (!(gMapSelectFlags & MAP_SELECT_FLAG_ENABLE))
+            if (!gMapSelectFlags.has(MapSelectFlag::enable))
             {
-                gMapSelectFlags |= MAP_SELECT_FLAG_ENABLE;
+                gMapSelectFlags.set(MapSelectFlag::enable);
                 state_changed++;
             }
 
-            if (gMapSelectType != MAP_SELECT_TYPE_FULL)
+            if (gMapSelectType != MapSelectType::full)
             {
-                gMapSelectType = MAP_SELECT_TYPE_FULL;
+                gMapSelectType = MapSelectType::full;
                 state_changed++;
             }
 
-            if ((gMapSelectType != MAP_SELECT_TYPE_EDGE_0 + (side & 0xFF)) && mapCtrlPressed)
+            MapSelectType selectedSide = getMapSelectEdge(side & 0xFF);
+            if (gMapSelectType != selectedSide && mapCtrlPressed)
             {
-                gMapSelectType = MAP_SELECT_TYPE_EDGE_0 + (side & 0xFF);
+                gMapSelectType = selectedSide;
                 state_changed++;
             }
 
@@ -754,14 +771,14 @@ namespace OpenRCT2::Ui::Windows
             // Decide on shape of the brush for bigger selection size
             switch (gMapSelectType)
             {
-                case MAP_SELECT_TYPE_EDGE_0:
-                case MAP_SELECT_TYPE_EDGE_2:
+                case MapSelectType::edge0:
+                case MapSelectType::edge2:
                     // Line
                     mapTile->y -= (tool_size - 1) * 16;
                     mapTile->y = mapTile->ToTileStart().y;
                     break;
-                case MAP_SELECT_TYPE_EDGE_1:
-                case MAP_SELECT_TYPE_EDGE_3:
+                case MapSelectType::edge1:
+                case MapSelectType::edge3:
                     // Line
                     mapTile->x -= (tool_size - 1) * 16;
                     mapTile->x = mapTile->ToTileStart().x;
@@ -789,17 +806,17 @@ namespace OpenRCT2::Ui::Windows
             // Go to other side
             switch (gMapSelectType)
             {
-                case MAP_SELECT_TYPE_EDGE_0:
-                case MAP_SELECT_TYPE_EDGE_2:
+                case MapSelectType::edge0:
+                case MapSelectType::edge2:
                     // Line
                     mapTile->y += tool_length;
-                    gMapSelectType = MAP_SELECT_TYPE_FULL;
+                    gMapSelectType = MapSelectType::full;
                     break;
-                case MAP_SELECT_TYPE_EDGE_1:
-                case MAP_SELECT_TYPE_EDGE_3:
+                case MapSelectType::edge1:
+                case MapSelectType::edge3:
                     // Line
                     mapTile->x += tool_length;
-                    gMapSelectType = MAP_SELECT_TYPE_FULL;
+                    gMapSelectType = MapSelectType::full;
                     break;
                 default:
                     mapTile->x += tool_length;
@@ -819,22 +836,21 @@ namespace OpenRCT2::Ui::Windows
                 state_changed++;
             }
 
-            MapInvalidateSelectionRect();
             if (!state_changed)
                 return;
 
-            money64 lower_cost = SelectionLowerLand(0);
-            money64 raise_cost = SelectionRaiseLand(0);
+            money64 lower_cost = SelectionLowerLand(SelectionMode::query);
+            money64 raise_cost = SelectionRaiseLand(SelectionMode::query);
 
             if (_landToolRaiseCost != raise_cost || _landToolLowerCost != lower_cost)
             {
                 _landToolRaiseCost = raise_cost;
                 _landToolLowerCost = lower_cost;
-                windowMgr->InvalidateByClass(WindowClass::Land);
+                windowMgr->InvalidateByClass(WindowClass::land);
             }
         }
 
-        void DrawDropdownButtons(RenderTarget& rt)
+        void DrawDropdownButtons(Drawing::RenderTarget& rt)
         {
             auto& objManager = GetContext()->GetObjectManager();
             const auto* surfaceObj = objManager.GetLoadedObject<TerrainSurfaceObject>(_selectedFloorTexture);
@@ -842,7 +858,7 @@ namespace OpenRCT2::Ui::Windows
             if (surfaceObj != nullptr)
             {
                 surfaceImage = ImageId(surfaceObj->IconImageId);
-                if (surfaceObj->Colour != TerrainSurfaceObject::kNoValue)
+                if (surfaceObj->Colour != Drawing::kColourNull)
                     surfaceImage = surfaceImage.WithPrimary(surfaceObj->Colour);
             }
 
@@ -857,7 +873,7 @@ namespace OpenRCT2::Ui::Windows
             DrawDropdownButton(rt, WIDX_WALL, edgeImage);
         }
 
-        void DrawDropdownButton(RenderTarget& rt, WidgetIndex widgetIndex, ImageId image)
+        void DrawDropdownButton(Drawing::RenderTarget& rt, WidgetIndex widgetIndex, ImageId image)
         {
             const auto& widget = widgets[widgetIndex];
             GfxDrawSprite(rt, image, { windowPos.x + widget.left, windowPos.y + widget.top });
@@ -868,7 +884,7 @@ namespace OpenRCT2::Ui::Windows
     {
         auto* windowMgr = GetWindowManager();
         return windowMgr->FocusOrCreate<LandWindow>(
-            WindowClass::Land, ScreenCoordsXY(ContextGetWidth() - kWindowSize.width, 29), kWindowSize, 0);
+            WindowClass::land, ScreenCoordsXY(ContextGetWidth() - kWindowSize.width, 29), kWindowSize, {});
     }
 
     /**
@@ -877,16 +893,16 @@ namespace OpenRCT2::Ui::Windows
      */
     void ToggleLandWindow()
     {
-        if (isToolActive(WindowClass::Land, WIDX_BACKGROUND))
+        if (isToolActive(WindowClass::land, WIDX_BACKGROUND))
         {
             ToolCancel();
         }
         else
         {
             ShowGridlines();
-            auto* toolWindow = ContextOpenWindow(WindowClass::Land);
+            auto* toolWindow = ContextOpenWindow(WindowClass::land);
             ToolSet(*toolWindow, WIDX_BACKGROUND, Tool::digDown);
-            gInputFlags.set(InputFlag::unk6);
+            gInputFlags.set(InputFlag::allowRightMouseRemoval);
         }
     }
 } // namespace OpenRCT2::Ui::Windows
