@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2025 OpenRCT2 developers
+ * Copyright (c) 2014-2026 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -15,6 +15,7 @@
 #include <openrct2/GameState.h>
 #include <openrct2/SpriteIds.h>
 #include <openrct2/actions/ParkSetResearchFundingAction.h>
+#include <openrct2/drawing/Drawing.h>
 #include <openrct2/localisation/Formatter.h>
 #include <openrct2/localisation/Localisation.Date.h>
 #include <openrct2/management/Finance.h>
@@ -246,7 +247,7 @@ namespace OpenRCT2::Ui::Windows
             }
         }
 
-        void onDraw(RenderTarget& rt) override
+        void onDraw(Drawing::RenderTarget& rt) override
         {
             drawWidgets(rt);
             DrawTabImages(rt);
@@ -266,7 +267,7 @@ namespace OpenRCT2::Ui::Windows
             }
         }
 
-        void DrawTabImage(RenderTarget& rt, int32_t tabPage, int32_t spriteIndex)
+        void DrawTabImage(Drawing::RenderTarget& rt, int32_t tabPage, int32_t spriteIndex)
         {
             WidgetIndex widgetIndex = WIDX_TAB_1 + tabPage;
 
@@ -286,7 +287,7 @@ namespace OpenRCT2::Ui::Windows
             }
         }
 
-        void DrawTabImages(RenderTarget& rt)
+        void DrawTabImages(Drawing::RenderTarget& rt)
         {
             DrawTabImage(rt, WINDOW_RESEARCH_PAGE_DEVELOPMENT, SPR_TAB_FINANCES_RESEARCH_0);
             DrawTabImage(rt, WINDOW_RESEARCH_PAGE_FUNDING, SPR_TAB_FINANCES_SUMMARY_0);
@@ -340,7 +341,7 @@ namespace OpenRCT2::Ui::Windows
         }
     }
 
-    void WindowResearchDevelopmentDraw(WindowBase* w, RenderTarget& rt, WidgetIndex baseWidgetIndex)
+    void WindowResearchDevelopmentDraw(WindowBase* w, Drawing::RenderTarget& rt, WidgetIndex baseWidgetIndex)
     {
         const auto& gameState = getGameState();
 
@@ -482,8 +483,8 @@ namespace OpenRCT2::Ui::Windows
             gDropdown.items[i] = Dropdown::MenuLabel(kResearchFundingLevelNames[i]);
         }
         WindowDropdownShowTextCustomWidth(
-            { w->windowPos.x + dropdownWidget->left, w->windowPos.y + dropdownWidget->top }, dropdownWidget->height() + 1,
-            w->colours[1], 0, Dropdown::Flag::StayOpen, 4, dropdownWidget->width() - 3);
+            { w->windowPos.x + dropdownWidget->left, w->windowPos.y + dropdownWidget->top }, dropdownWidget->height(),
+            w->colours[1], 0, Dropdown::Flag::StayOpen, 4, dropdownWidget->width() - 4);
 
         int32_t currentResearchLevel = gameState.researchFundingLevel;
         gDropdown.items[currentResearchLevel].setChecked(true);
@@ -573,7 +574,7 @@ namespace OpenRCT2::Ui::Windows
         }
     }
 
-    void WindowResearchFundingDraw(WindowBase* w, RenderTarget& rt)
+    void WindowResearchFundingDraw(WindowBase* w, Drawing::RenderTarget& rt)
     {
         const auto& gameState = getGameState();
         if (gameState.park.flags & PARK_FLAGS_NO_MONEY)
