@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2025 OpenRCT2 developers
+ * Copyright (c) 2014-2026 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -27,6 +27,7 @@
 #include <openrct2/config/Config.h>
 #include <openrct2/core/EnumUtils.hpp>
 #include <openrct2/core/String.hpp>
+#include <openrct2/drawing/ColourMap.h>
 #include <openrct2/drawing/Drawing.h>
 #include <openrct2/drawing/Rectangle.h>
 #include <openrct2/entity/EntityList.h>
@@ -331,7 +332,7 @@ namespace OpenRCT2::Ui::Windows
             auto i = static_cast<size_t>(screenCoords.y / kScrollableRowHeight);
             if (i != _highlightedIndex)
             {
-                _highlightedIndex = static_cast<size_t>(i);
+                _highlightedIndex = i;
                 invalidate();
             }
         }
@@ -372,7 +373,7 @@ namespace OpenRCT2::Ui::Windows
             auto rtCoords = ScreenCoordsXY{ rt.x, rt.y };
             Rectangle::fill(
                 rt, { rtCoords, rtCoords + ScreenCoordsXY{ rt.width - 1, rt.height - 1 } },
-                ColourMapA[colours[1].colour].mid_light);
+                getColourMap(colours[1].colour).midLight);
 
             // How much space do we have for the name and action columns? (Discount scroll area and icons.)
             const int32_t nonIconSpace = widgets[WIDX_STAFF_LIST_LIST].width() - 1 - 15 - 68;
@@ -546,10 +547,10 @@ namespace OpenRCT2::Ui::Windows
 
             auto hireStaffAction = GameActions::StaffHireNewAction(autoPosition, staffType, costume, staffOrders);
             hireStaffAction.SetCallback([=](const GameActions::GameAction*, const GameActions::Result* res) -> void {
-                if (res->Error != GameActions::Status::Ok)
+                if (res->error != GameActions::Status::ok)
                     return;
 
-                auto actionResult = res->GetData<GameActions::StaffHireNewActionResult>();
+                auto actionResult = res->getData<GameActions::StaffHireNewActionResult>();
                 auto* staff = getGameState().entities.GetEntity<Staff>(actionResult.StaffEntityId);
                 if (staff == nullptr)
                     return;
@@ -564,7 +565,7 @@ namespace OpenRCT2::Ui::Windows
                                                                 Network::GetCurrentPlayerId() };
                     pickupAction.SetCallback(
                         [staffId = staff->Id](const GameActions::GameAction* ga, const GameActions::Result* result) {
-                            if (result->Error != GameActions::Status::Ok)
+                            if (result->error != GameActions::Status::ok)
                                 return;
 
                             auto* staff2 = getGameState().entities.GetEntity<Staff>(staffId);
@@ -604,7 +605,7 @@ namespace OpenRCT2::Ui::Windows
             DrawTabImage(rt, WINDOW_STAFF_LIST_TAB_ENTERTAINERS, AnimationPeepType::entertainer);
         }
 
-        void DrawTabImage(RenderTarget& rt, int32_t tabIndex, AnimationPeepType type, colour_t colour) const
+        void DrawTabImage(RenderTarget& rt, int32_t tabIndex, AnimationPeepType type, Drawing::Colour colour) const
         {
             PeepAnimationsObject* animObj = findPeepAnimationsObjectForType(type);
             if (animObj == nullptr)
@@ -631,16 +632,16 @@ namespace OpenRCT2::Ui::Windows
             auto widgetIndex = WIDX_STAFF_LIST_HANDYMEN_TAB + tabIndex;
             const auto& widget = widgets[widgetIndex];
 
-            RenderTarget clippedDpi;
-            if (ClipDrawPixelInfo(
-                    clippedDpi, rt, windowPos + ScreenCoordsXY{ widget.left + 1, widget.top + 1 },
+            RenderTarget clippedRT;
+            if (ClipRenderTarget(
+                    clippedRT, rt, windowPos + ScreenCoordsXY{ widget.left + 1, widget.top + 1 },
                     widget.right - widget.left - 1, widget.bottom - widget.top - 1))
             {
                 auto frame = _selectedTab == tabIndex ? _tabAnimationIndex / 4 : 0;
                 auto& anim = animObj->GetPeepAnimation(PeepAnimationGroup::normal);
                 auto imageId = anim.baseImage + 1 + anim.frameOffsets[frame] * 4;
 
-                GfxDrawSprite(clippedDpi, ImageId(imageId), { 15, 23 });
+                GfxDrawSprite(clippedRT, ImageId(imageId), { 15, 23 });
             }
         }
 
