@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2025 OpenRCT2 developers
+ * Copyright (c) 2014-2026 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -19,6 +19,7 @@
 #include "Game.h"
 #include "GameState.h"
 #include "GameStateSnapshots.h"
+#include "Input.h"
 #include "OpenRCT2.h"
 #include "ParkImporter.h"
 #include "PlatformEnvironment.h"
@@ -38,10 +39,13 @@
 #include "core/Path.hpp"
 #include "core/String.hpp"
 #include "core/Timer.hpp"
+#include "drawing/ColourMap.h"
+#include "drawing/Drawing.h"
 #include "drawing/IDrawingEngine.h"
 #include "drawing/Image.h"
 #include "drawing/LightFX.h"
 #include "entity/EntityTweener.h"
+#include "entity/PatrolArea.h"
 #include "interface/Chat.h"
 #include "interface/StdInOutConsole.h"
 #include "interface/Viewport.h"
@@ -72,6 +76,7 @@
 #include "ui/UiContext.h"
 #include "ui/WindowManager.h"
 #include "world/MapAnimation.h"
+#include "world/MapSelection.h"
 
 #include <chrono>
 #include <cmath>
@@ -82,10 +87,6 @@
 #include <string>
 
 using namespace OpenRCT2;
-using namespace OpenRCT2::Drawing;
-using namespace OpenRCT2::Localisation;
-using namespace OpenRCT2::Paint;
-using namespace OpenRCT2::Scripting;
 using namespace OpenRCT2::Ui;
 
 using OpenRCT2::Audio::IAudioContext;
@@ -108,7 +109,7 @@ namespace OpenRCT2
         std::unique_ptr<IUiContext> const _uiContext;
 
         // Services
-        std::unique_ptr<LocalisationService> _localisationService;
+        std::unique_ptr<Localisation::LocalisationService> _localisationService;
         std::unique_ptr<IObjectRepository> _objectRepository;
         std::unique_ptr<IObjectManager> _objectManager;
         std::unique_ptr<ITrackDesignRepository> _trackDesignRepository;
@@ -121,7 +122,7 @@ namespace OpenRCT2
 #endif
         StdInOutConsole _stdInOutConsole;
 #ifdef ENABLE_SCRIPTING
-        ScriptEngine _scriptEngine;
+        Scripting::ScriptEngine _scriptEngine;
 #endif
 #ifndef DISABLE_NETWORK
         Network::NetworkBase _network;
@@ -135,8 +136,8 @@ namespace OpenRCT2
         IScene* _activeScene = nullptr;
 
         DrawingEngine _drawingEngineType = DrawingEngine::SoftwareWithHardwareDisplay;
-        std::unique_ptr<IDrawingEngine> _drawingEngine;
-        std::unique_ptr<Painter> _painter;
+        std::unique_ptr<Drawing::IDrawingEngine> _drawingEngine;
+        std::unique_ptr<Paint::Painter> _painter;
 
         bool _initialised = false;
 
@@ -173,7 +174,7 @@ namespace OpenRCT2
             : _env(std::move(env))
             , _audioContext(std::move(audioContext))
             , _uiContext(std::move(uiContext))
-            , _localisationService(std::make_unique<LocalisationService>(*_env))
+            , _localisationService(std::make_unique<Localisation::LocalisationService>(*_env))
             , _replayManager(CreateReplayManager())
             , _gameStateSnapshots(CreateGameStateSnapshots())
 #ifdef ENABLE_SCRIPTING
@@ -182,7 +183,7 @@ namespace OpenRCT2
 #ifndef DISABLE_NETWORK
             , _network(*this)
 #endif
-            , _painter(std::make_unique<Painter>(*_uiContext))
+            , _painter(std::make_unique<Paint::Painter>(*_uiContext))
         {
             // Can't have more than one context currently.
             Guard::Assert(Instance == nullptr);
@@ -206,7 +207,7 @@ namespace OpenRCT2
             _network.Close();
 #endif
 
-            auto* windowMgr = Ui::GetWindowManager();
+            auto* windowMgr = GetWindowManager();
             windowMgr->CloseAll();
 
             // Unload objects after closing all windows, this is to overcome windows like
@@ -218,7 +219,7 @@ namespace OpenRCT2
 
             GfxObjectCheckAllImagesFreed();
             GfxUnloadCsg();
-            GfxUnloadG2AndFonts();
+            GfxUnloadG2PalettesFontsTracks();
             GfxUnloadG1();
             Audio::Close();
 
@@ -292,7 +293,7 @@ namespace OpenRCT2
             return _drawingEngineType;
         }
 
-        IDrawingEngine* GetDrawingEngine() override
+        Drawing::IDrawingEngine* GetDrawingEngine() override
         {
             return _drawingEngine.get();
         }
@@ -409,20 +410,20 @@ namespace OpenRCT2
 
             CrashInit();
 
-            if (String::equals(Config::Get().general.LastRunVersion, kOpenRCT2Version))
+            if (String::equals(Config::Get().general.lastRunVersion, kOpenRCT2Version))
             {
                 gOpenRCT2ShowChangelog = false;
             }
             else
             {
                 gOpenRCT2ShowChangelog = true;
-                Config::Get().general.LastRunVersion = kOpenRCT2Version;
+                Config::Get().general.lastRunVersion = kOpenRCT2Version;
                 Config::Save();
             }
 
             try
             {
-                _localisationService->OpenLanguage(Config::Get().general.Language);
+                _localisationService->OpenLanguage(Config::Get().general.language);
             }
             catch (const std::exception& e)
             {
@@ -480,6 +481,7 @@ namespace OpenRCT2
             }
 #endif
 
+#ifndef __HAIKU__ // Haiku's user is always root, skip warning them about it.
             if (Platform::ProcessIsElevated())
             {
                 std::string elevationWarning = _localisationService->GetString(STR_ADMIN_NOT_RECOMMENDED);
@@ -492,6 +494,7 @@ namespace OpenRCT2
                     _uiContext->ShowMessageBox(elevationWarning);
                 }
             }
+#endif
 
             if (Platform::IsRunningInWine())
             {
@@ -518,7 +521,7 @@ namespace OpenRCT2
                 Audio::Init();
                 Audio::PopulateDevices();
                 Audio::InitRideSoundsAndInfo();
-                Audio::gGameSoundsOff = !Config::Get().sound.MasterSoundEnabled;
+                Audio::gGameSoundsOff = !Config::Get().sound.masterSoundEnabled;
             }
 
             ChatInit();
@@ -533,9 +536,8 @@ namespace OpenRCT2
                 Drawing::LightFx::Init();
             }
 
-            ViewportInitAll();
-
             ContextInit();
+            ResetSubsystems();
 
             if (!gOpenRCT2Headless)
             {
@@ -555,6 +557,28 @@ namespace OpenRCT2
             return true;
         }
 
+        /**
+         *  rct2: 0x006E6EAC
+         */
+        void ResetSubsystems() override
+        {
+            if (!gOpenRCT2NoGraphics)
+            {
+                Drawing::initColourMaps();
+            }
+
+            WindowInitAll();
+
+            gInputFlags.clearAll();
+            InputSetState(InputState::Reset);
+            gPressedWidget.windowClassification = WindowClass::null;
+            gPickupPeepImage = ImageId();
+            ResetTooltipNotShown();
+            gMapSelectFlags.clearAll();
+            ClearPatrolAreaToRender();
+            TextinputCancel();
+        }
+
     private:
         void InitialiseRepositories()
         {
@@ -610,7 +634,7 @@ namespace OpenRCT2
         {
             assert(_drawingEngine == nullptr);
 
-            const auto initializeEngine = [&](DrawingEngine engine) -> std::unique_ptr<IDrawingEngine> {
+            const auto initializeEngine = [&](DrawingEngine engine) -> std::unique_ptr<Drawing::IDrawingEngine> {
                 try
                 {
                     auto drawingEngineFactory = _uiContext->GetDrawingEngineFactory();
@@ -622,7 +646,7 @@ namespace OpenRCT2
                     }
 
                     drawingEngine->Initialise();
-                    drawingEngine->SetVSync(Config::Get().general.UseVSync);
+                    drawingEngine->SetVSync(Config::Get().general.useVSync);
 
                     return drawingEngine;
                 }
@@ -634,7 +658,7 @@ namespace OpenRCT2
                 return nullptr;
             };
 
-            auto drawingEngineType = Config::Get().general.DrawingEngine;
+            auto drawingEngineType = Config::Get().general.drawingEngine;
 
             // Attempt to create drawing engine of the type specified in the config.
             {
@@ -667,7 +691,7 @@ namespace OpenRCT2
 
             _drawingEngineType = drawingEngineType;
 
-            Config::Get().general.DrawingEngine = drawingEngineType;
+            Config::Get().general.drawingEngine = drawingEngineType;
             Config::Save();
 
             WindowCheckAllValidZoom();
@@ -705,7 +729,7 @@ namespace OpenRCT2
             if (!gOpenRCT2Headless && isMainThread)
             {
                 _uiContext->ProcessMessages();
-                auto* windowMgr = Ui::GetWindowManager();
+                auto* windowMgr = GetWindowManager();
                 windowMgr->InvalidateByClass(WindowClass::progressWindow);
                 Draw();
             }
@@ -1006,11 +1030,11 @@ namespace OpenRCT2
             if (gCustomRCT2DataPath.empty())
             {
                 // Check install directory
-                if (Config::Get().general.RCT2Path.empty() || !Platform::OriginalGameDataExists(Config::Get().general.RCT2Path))
+                if (Config::Get().general.rct2Path.empty() || !Platform::OriginalGameDataExists(Config::Get().general.rct2Path))
                 {
                     LOG_VERBOSE(
                         "install directory does not exist or invalid directory selected, %s",
-                        Config::Get().general.RCT2Path.c_str());
+                        Config::Get().general.rct2Path.c_str());
                     if (!Config::FindOrBrowseInstallDirectory())
                     {
                         auto path = Config::GetDefaultPath();
@@ -1019,7 +1043,7 @@ namespace OpenRCT2
                         return std::string();
                     }
                 }
-                result = Config::Get().general.RCT2Path;
+                result = Config::Get().general.rct2Path;
             }
             else
             {
@@ -1035,7 +1059,7 @@ namespace OpenRCT2
             {
                 return false;
             }
-            GfxLoadG2FontsAndTracks();
+            GfxLoadG2PalettesFontsTracks();
             GfxLoadCsg();
             FontSpriteInitialiseCharacters();
             return true;
@@ -1053,7 +1077,7 @@ namespace OpenRCT2
             }
             else
             {
-                if ((gOpenRCT2StartupAction == StartupAction::Title) && Config::Get().general.PlayIntro)
+                if ((gOpenRCT2StartupAction == StartupAction::Title) && Config::Get().general.playIntro)
                 {
                     gOpenRCT2StartupAction = StartupAction::Intro;
                 }
@@ -1159,17 +1183,17 @@ namespace OpenRCT2
                 {
                     if (gNetworkStartPort == 0)
                     {
-                        gNetworkStartPort = Config::Get().network.DefaultPort;
+                        gNetworkStartPort = Config::Get().network.defaultPort;
                     }
 
                     if (gNetworkStartAddress.empty())
                     {
-                        gNetworkStartAddress = Config::Get().network.ListenAddress;
+                        gNetworkStartAddress = Config::Get().network.listenAddress;
                     }
 
                     if (gCustomPassword.empty())
                     {
-                        _network.SetPassword(Config::Get().network.DefaultPassword.c_str());
+                        _network.SetPassword(Config::Get().network.defaultPassword.c_str());
                     }
                     else
                     {
@@ -1190,7 +1214,7 @@ namespace OpenRCT2
             {
                 if (gNetworkStartPort == 0)
                 {
-                    gNetworkStartPort = Config::Get().network.DefaultPort;
+                    gNetworkStartPort = Config::Get().network.defaultPort;
                 }
                 _network.BeginClient(gNetworkStartHost, gNetworkStartPort);
             }
@@ -1215,7 +1239,7 @@ namespace OpenRCT2
 
             if (!gOpenRCT2Headless)
             {
-                _preloaderScene->SetOnComplete([&]() { SwitchToStartUpScene(); });
+                GetPreloaderScene()->SetOnComplete([&]() { SwitchToStartUpScene(); });
             }
             else
             {
@@ -1251,7 +1275,7 @@ namespace OpenRCT2
         {
             if (!ShouldDraw())
                 return false;
-            if (!Config::Get().general.UncapFPS)
+            if (!Config::Get().general.uncapFPS)
                 return false;
             if (gGameSpeed > 4)
                 return false;
@@ -1299,6 +1323,8 @@ namespace OpenRCT2
 
             UpdateTimeAccumulators(deltaTime);
 
+            Network::Update();
+
             if (useVariableFrame)
             {
                 RunVariableFrame(deltaTime);
@@ -1307,6 +1333,8 @@ namespace OpenRCT2
             {
                 RunFixedFrame(deltaTime);
             }
+
+            Network::Flush();
         }
 
         void UpdateTimeAccumulators(float deltaTime)
@@ -1332,7 +1360,7 @@ namespace OpenRCT2
 
             if (_ticksAccumulator < kGameUpdateTimeMS)
             {
-                const auto sleepTimeSec = (kGameUpdateTimeMS - _ticksAccumulator);
+                const auto sleepTimeSec = std::min(kNetworkUpdateTimeMS, kGameUpdateTimeMS - _ticksAccumulator);
                 Platform::Sleep(static_cast<uint32_t>(sleepTimeSec * 1000.f));
                 return;
             }
@@ -1580,7 +1608,7 @@ namespace OpenRCT2
     }
 
     std::unique_ptr<IContext> CreateContext(
-        std::unique_ptr<IPlatformEnvironment>&& env, std::unique_ptr<Audio::IAudioContext>&& audioContext,
+        std::unique_ptr<IPlatformEnvironment>&& env, std::unique_ptr<IAudioContext>&& audioContext,
         std::unique_ptr<IUiContext>&& uiContext)
     {
         return std::make_unique<Context>(std::move(env), std::move(audioContext), std::move(uiContext));
@@ -1596,6 +1624,11 @@ namespace OpenRCT2
         GetWindowManager()->Init();
     }
 
+    void ContextResetSubsystems()
+    {
+        GetContext()->ResetSubsystems();
+    }
+
     bool ContextLoadParkFromStream(void* stream)
     {
         return GetContext()->LoadParkFromStream(static_cast<IStream*>(stream), "");
@@ -1608,7 +1641,7 @@ namespace OpenRCT2
 
     void ContextUpdateCursorScale()
     {
-        GetContext()->GetUiContext().SetCursorScale(static_cast<uint8_t>(std::round(Config::Get().general.WindowScale)));
+        GetContext()->GetUiContext().SetCursorScale(static_cast<uint8_t>(std::round(Config::Get().general.windowScale)));
     }
 
     void ContextHideCursor()
@@ -1630,8 +1663,8 @@ namespace OpenRCT2
     {
         auto cursorCoords = ContextGetCursorPosition();
         // Compensate for window scaling.
-        return { static_cast<int32_t>(std::ceil(cursorCoords.x / Config::Get().general.WindowScale)),
-                 static_cast<int32_t>(std::ceil(cursorCoords.y / Config::Get().general.WindowScale)) };
+        return { static_cast<int32_t>(std::ceil(cursorCoords.x / Config::Get().general.windowScale)),
+                 static_cast<int32_t>(std::ceil(cursorCoords.y / Config::Get().general.windowScale)) };
     }
 
     void ContextSetCursorPosition(const ScreenCoordsXY& cursorPosition)
@@ -1706,55 +1739,55 @@ namespace OpenRCT2
 
     WindowBase* ContextOpenWindow(WindowClass wc)
     {
-        auto windowManager = Ui::GetWindowManager();
+        auto windowManager = GetWindowManager();
         return windowManager->OpenWindow(wc);
     }
 
     WindowBase* ContextOpenWindowView(WindowView view)
     {
-        auto windowManager = Ui::GetWindowManager();
+        auto windowManager = GetWindowManager();
         return windowManager->openView(view);
     }
 
     WindowBase* ContextOpenDetailWindow(WindowDetail type, int32_t id)
     {
-        auto windowManager = Ui::GetWindowManager();
+        auto windowManager = GetWindowManager();
         return windowManager->openDetails(type, id);
     }
 
     WindowBase* ContextOpenIntent(Intent* intent)
     {
-        auto windowManager = Ui::GetWindowManager();
+        auto windowManager = GetWindowManager();
         return windowManager->OpenIntent(intent);
     }
 
     void ContextBroadcastIntent(Intent* intent)
     {
-        auto windowManager = Ui::GetWindowManager();
+        auto windowManager = GetWindowManager();
         windowManager->BroadcastIntent(*intent);
     }
 
     void ContextForceCloseWindowByClass(WindowClass windowClass)
     {
-        auto windowManager = Ui::GetWindowManager();
+        auto windowManager = GetWindowManager();
         windowManager->ForceClose(windowClass);
     }
 
     WindowBase* ContextShowError(StringId title, StringId message, const Formatter& args, const bool autoClose /* = false */)
     {
-        auto windowManager = Ui::GetWindowManager();
+        auto windowManager = GetWindowManager();
         return windowManager->ShowError(title, message, args, autoClose);
     }
 
     void ContextHandleInput()
     {
-        auto windowManager = Ui::GetWindowManager();
+        auto windowManager = GetWindowManager();
         windowManager->HandleInput();
     }
 
     void ContextInputHandleKeyboard(bool isTitle)
     {
-        auto windowManager = Ui::GetWindowManager();
+        auto windowManager = GetWindowManager();
         windowManager->HandleKeyboard(isTitle);
     }
 
@@ -1763,7 +1796,7 @@ namespace OpenRCT2
         GetContext()->Quit();
     }
 
-    u8string ContextOpenCommonFileDialog(Ui::FileDialogDesc& desc)
+    u8string ContextOpenCommonFileDialog(FileDialogDesc& desc)
     {
         try
         {
