@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2025 OpenRCT2 developers
+ * Copyright (c) 2014-2026 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -178,7 +178,7 @@ namespace OpenRCT2::GameActions
         {
             ride->proposedNumTrains = 32;
         }
-        ride->maxTrains = OpenRCT2::Limits::kMaxTrainsPerRide;
+        ride->maxTrains = Limits::kMaxTrainsPerRide;
         ride->numCarsPerTrain = 1;
         ride->proposedNumCarsPerTrain = rideEntry->max_cars_in_train;
         ride->minWaitingTime = 10;
@@ -188,7 +188,7 @@ namespace OpenRCT2::GameActions
         const auto& rtd = ride->getRideTypeDescriptor();
         if (rtd.HasFlag(RtdFlag::allowMusic))
         {
-            auto& objManager = OpenRCT2::GetContext()->GetObjectManager();
+            auto& objManager = GetContext()->GetObjectManager();
             ride->music = objManager.GetLoadedObjectEntryIndex(rtd.DefaultMusic);
             if (ride->music != kObjectEntryIndexNull)
             {
