@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2025 OpenRCT2 developers
+ * Copyright (c) 2014-2026 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -17,20 +17,22 @@ namespace OpenRCT2::GameActions
     {
     private:
         CoordsXYZD _loc;
-        int32_t _primaryColour{};
-        int32_t _secondaryColour{};
-        int32_t _tertiaryColour{};
+        Drawing::Colour _primaryColour{};
+        Drawing::Colour _secondaryColour{};
+        Drawing::Colour _tertiaryColour{};
 
     public:
         WallSetColourAction() = default;
-        WallSetColourAction(const CoordsXYZD& loc, int32_t primaryColour, int32_t secondaryColour, int32_t tertiaryColour);
+        WallSetColourAction(
+            const CoordsXYZD& loc, Drawing::Colour primaryColour, Drawing::Colour secondaryColour,
+            Drawing::Colour tertiaryColour);
 
         void AcceptParameters(GameActionParameterVisitor&) final;
 
         uint16_t GetActionFlags() const override;
 
         void Serialise(DataSerialiser& stream) override;
-        Result Query() const override;
-        Result Execute() const override;
+        Result Query(GameState_t& gameState) const override;
+        Result Execute(GameState_t& gameState) const override;
     };
 } // namespace OpenRCT2::GameActions
