@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2025 OpenRCT2 developers
+ * Copyright (c) 2014-2026 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -23,6 +23,8 @@
 #include "../ride/RideAudio.h"
 #include "../ui/UiContext.h"
 #include "../ui/WindowManager.h"
+#include "../world/Map.h"
+#include "../world/MapSelection.h"
 #include "Viewport.h"
 #include "Widget.h"
 #include "WindowBase.h"
@@ -36,13 +38,13 @@
 namespace OpenRCT2
 {
 
-    std::vector<std::unique_ptr<WindowBase>> g_window_list;
+    std::vector<std::unique_ptr<WindowBase>> gWindowList;
     WindowBase* gWindowAudioExclusive;
 
-    WindowCloseModifier gLastCloseModifier = { { WindowClass::Null, 0 }, CloseWindowModifier::none };
+    WindowCloseModifier gLastCloseModifier = { { WindowClass::null, 0 }, CloseWindowModifier::none };
 
     uint32_t gWindowUpdateTicks;
-    colour_t gCurrentWindowColours[3];
+    Drawing::Colour gCurrentWindowColours[3];
 
     Tool gCurrentToolId;
     WidgetRef gCurrentToolWidget;
@@ -71,19 +73,22 @@ static constexpr float kWindowScrollLocations[][2] = {
 };
     // clang-format on
 
-    static void WindowDrawCore(RenderTarget& rt, WindowBase& w, int32_t left, int32_t top, int32_t right, int32_t bottom);
-    static void WindowDrawSingle(RenderTarget& rt, WindowBase& w, int32_t left, int32_t top, int32_t right, int32_t bottom);
+    static void WindowDrawCore(
+        Drawing::RenderTarget& rt, WindowBase& w, int32_t left, int32_t top, int32_t right, int32_t bottom);
+    static void WindowDrawSingle(
+        Drawing::RenderTarget& rt, WindowBase& w, int32_t left, int32_t top, int32_t right, int32_t bottom);
 
     std::vector<std::unique_ptr<WindowBase>>::iterator WindowGetIterator(const WindowBase* w)
     {
-        return std::find_if(g_window_list.begin(), g_window_list.end(), [w](auto&& w2) { return w == w2.get(); });
+        return std::find_if(gWindowList.begin(), gWindowList.end(), [w](auto&& w2) { return w == w2.get(); });
     }
 
     void WindowVisitEach(std::function<void(WindowBase*)> func)
     {
-        for (auto& w : g_window_list)
+        for (size_t i = 0; i < gWindowList.size(); i++)
         {
-            if (w->flags & WF_DEAD)
+            auto& w = gWindowList[i];
+            if (w->flags.has(WindowFlag::dead))
                 continue;
             func(w.get());
         }
@@ -109,7 +114,7 @@ static constexpr float kWindowScrollLocations[][2] = {
     void WindowDispatchUpdateAll()
     {
         // gTooltipNotShownTicks++;
-        WindowVisitEach([&](WindowBase* w) { w->OnUpdate(); });
+        WindowVisitEach([&](WindowBase* w) { w->onUpdate(); });
     }
 
     void WindowUpdateAllViewports()
@@ -124,8 +129,8 @@ static constexpr float kWindowScrollLocations[][2] = {
 
     static void WindowUpdateVisibilities()
     {
-        const auto itEnd = g_window_list.end();
-        for (auto it = g_window_list.begin(); it != itEnd; ++it)
+        const auto itEnd = gWindowList.end();
+        for (auto it = gWindowList.begin(); it != itEnd; ++it)
         {
             auto& window = *(*it);
             if (window.viewport == nullptr)
@@ -133,7 +138,7 @@ static constexpr float kWindowScrollLocations[][2] = {
                 window.isVisible = true;
                 continue;
             }
-            if (window.classification == WindowClass::MainWindow)
+            if (window.classification == WindowClass::mainWindow)
             {
                 window.isVisible = true;
                 window.viewport->isVisible = true;
@@ -144,7 +149,7 @@ static constexpr float kWindowScrollLocations[][2] = {
             for (auto itOther = std::next(it); itOther != itEnd; ++itOther)
             {
                 const auto& otherWindow = *(*itOther);
-                if (otherWindow.flags & WF_DEAD)
+                if (otherWindow.flags.has(WindowFlag::dead))
                     continue;
 
                 if (otherWindow.windowPos.x <= window.windowPos.x && otherWindow.windowPos.y <= window.windowPos.y
@@ -165,27 +170,28 @@ static constexpr float kWindowScrollLocations[][2] = {
      */
     void WindowUpdateAll()
     {
-        // Remove all windows in g_window_list that have the WF_DEAD flag
-        g_window_list.erase(
-            std::remove_if(g_window_list.begin(), g_window_list.end(), [](auto&& w) -> bool { return w->flags & WF_DEAD; }),
-            g_window_list.end());
+        // Remove all windows in gWindowList that have the WindowFlag::dead flag
+        gWindowList.erase(
+            std::remove_if(
+                gWindowList.begin(), gWindowList.end(), [](auto&& w) -> bool { return w->flags.has(WindowFlag::dead); }),
+            gWindowList.end());
 
         // Periodic update happens every second so 40 ticks.
         if (gCurrentRealTimeTicks >= gWindowUpdateTicks)
         {
             gWindowUpdateTicks = gCurrentRealTimeTicks + kGameUpdateFPS;
 
-            WindowVisitEach([](WindowBase* w) { w->OnPeriodicUpdate(); });
+            WindowVisitEach([](WindowBase* w) { w->onPeriodicUpdate(); });
         }
 
         // Border flash invalidation
         WindowVisitEach([](WindowBase* w) {
-            if (w->flags & WF_WHITE_BORDER_MASK)
+            if (w->flashTimer > 0)
             {
-                w->flags -= WF_WHITE_BORDER_ONE;
-                if (!(w->flags & WF_WHITE_BORDER_MASK))
+                w->flashTimer--;
+                if (w->flashTimer == 0)
                 {
-                    w->Invalidate();
+                    w->invalidate();
                 }
             }
         });
@@ -198,7 +204,7 @@ static constexpr float kWindowScrollLocations[][2] = {
 
     void WindowNotifyLanguageChange()
     {
-        WindowVisitEach([&](WindowBase* w) { w->OnLanguageChange(); });
+        WindowVisitEach([&](WindowBase* w) { w->onLanguageChange(); });
     }
 
     /*
@@ -206,25 +212,23 @@ static constexpr float kWindowScrollLocations[][2] = {
      */
     void WindowSetWindowLimit(int32_t value)
     {
-        int32_t prev = Config::Get().general.WindowLimit;
+        int32_t prev = Config::Get().general.windowLimit;
         int32_t val = std::clamp<int32_t>(value, kWindowLimitMin, kWindowLimitMax);
-        Config::Get().general.WindowLimit = val;
+        Config::Get().general.windowLimit = val;
         Config::Save();
         // Checks if value decreases and then closes surplus
         // windows if one sets a limit lower than the number of windows open
         if (val < prev)
         {
             auto* windowMgr = Ui::GetWindowManager();
-            windowMgr->CloseSurplus(val, WindowClass::Options);
+            windowMgr->CloseSurplus(val, WindowClass::options);
         }
     }
 
     int32_t WindowGetScrollDataIndex(const WindowBase& w, WidgetIndex widget_index)
     {
-        int32_t i, result;
-
-        result = 0;
-        for (i = 0; i < widget_index; i++)
+        int32_t result = 0;
+        for (int32_t i = 0; i < widget_index; i++)
         {
             const auto& widget = w.widgets[i];
             if (widget.type == WidgetType::scroll)
@@ -242,7 +246,7 @@ static constexpr float kWindowScrollLocations[][2] = {
         WindowVisitEach([&window](WindowBase* w) {
             if (w == &window)
                 return;
-            if (w->flags & (WF_STICK_TO_BACK | WF_STICK_TO_FRONT))
+            if (w->flags.hasAny(WindowFlag::stickToBack, WindowFlag::stickToFront))
                 return;
             if (w->windowPos.x >= window.windowPos.x + window.width)
                 return;
@@ -253,12 +257,12 @@ static constexpr float kWindowScrollLocations[][2] = {
             if (w->windowPos.y + w->height <= window.windowPos.y)
                 return;
 
-            w->Invalidate();
+            w->invalidate();
             if (window.windowPos.x + window.width + 13 >= ContextGetWidth())
                 return;
             auto push_amount = window.windowPos.x + window.width - w->windowPos.x + 3;
             w->windowPos.x += push_amount;
-            w->Invalidate();
+            w->invalidate();
             if (w->viewport != nullptr)
                 w->viewport->pos.x += push_amount;
         });
@@ -275,7 +279,7 @@ static constexpr float kWindowScrollLocations[][2] = {
             if (&w1 == w2)
                 return;
             // ?
-            if (w2->flags & (WF_STICK_TO_BACK | WF_STICK_TO_FRONT))
+            if (w2->flags.hasAny(WindowFlag::stickToBack, WindowFlag::stickToFront))
                 return;
             // Check if w2 intersects with w1
             if (w2->windowPos.x > (w1.windowPos.x + w1.width) || w2->windowPos.x + w2->width < w1.windowPos.x)
@@ -288,13 +292,13 @@ static constexpr float kWindowScrollLocations[][2] = {
                 return;
 
             // Invalidate the window's current area
-            w2->Invalidate();
+            w2->invalidate();
 
             int32_t push_amount = w1.windowPos.y + w1.height - w2->windowPos.y + 3;
             w2->windowPos.y += push_amount;
 
             // Invalidate the window's new area
-            w2->Invalidate();
+            w2->invalidate();
 
             // Update viewport position if necessary
             if (w2->viewport != nullptr)
@@ -308,11 +312,11 @@ static constexpr float kWindowScrollLocations[][2] = {
      */
     WindowBase* WindowGetMain()
     {
-        for (auto& w : g_window_list)
+        for (auto& w : gWindowList)
         {
-            if (w->flags & WF_DEAD)
+            if (w->flags.has(WindowFlag::dead))
                 continue;
-            if (w->classification == WindowClass::MainWindow)
+            if (w->classification == WindowClass::mainWindow)
             {
                 return w.get();
             }
@@ -343,7 +347,7 @@ static constexpr float kWindowScrollLocations[][2] = {
             if (!(w.viewport->flags & VIEWPORT_FLAG_UNDERGROUND_INSIDE))
             {
                 w.viewport->flags |= VIEWPORT_FLAG_UNDERGROUND_INSIDE;
-                w.Invalidate();
+                w.invalidate();
             }
         }
         else
@@ -351,7 +355,7 @@ static constexpr float kWindowScrollLocations[][2] = {
             if (w.viewport->flags & VIEWPORT_FLAG_UNDERGROUND_INSIDE)
             {
                 w.viewport->flags &= ~VIEWPORT_FLAG_UNDERGROUND_INSIDE;
-                w.Invalidate();
+                w.invalidate();
             }
         }
 
@@ -367,9 +371,9 @@ static constexpr float kWindowScrollLocations[][2] = {
                 auto y2 = w.viewport->pos.y + static_cast<int32_t>(w.viewport->height * kWindowScrollLocations[i][1]);
 
                 auto it = WindowGetIterator(&w);
-                for (; it != g_window_list.end(); it++)
+                for (; it != gWindowList.end(); it++)
                 {
-                    if ((*it)->flags & WF_DEAD)
+                    if ((*it)->flags.has(WindowFlag::dead))
                         continue;
 
                     auto w2 = (*it).get();
@@ -386,7 +390,7 @@ static constexpr float kWindowScrollLocations[][2] = {
                         }
                     }
                 }
-                if (it == g_window_list.end())
+                if (it == gWindowList.end())
                 {
                     found = true;
                 }
@@ -399,14 +403,14 @@ static constexpr float kWindowScrollLocations[][2] = {
         }
 
         // rct2: 0x006E7C76
-        if (w.viewport_target_sprite.IsNull())
+        if (w.viewportTargetSprite.IsNull())
         {
-            if (!(w.flags & WF_NO_SCROLLING))
+            if (!w.flags.has(WindowFlag::noScrolling))
             {
                 w.savedViewPos = screenCoords
                     - ScreenCoordsXY{ static_cast<int32_t>(w.viewport->ViewWidth() * kWindowScrollLocations[i][0]),
                                       static_cast<int32_t>(w.viewport->ViewHeight() * kWindowScrollLocations[i][1]) };
-                w.flags |= WF_SCROLLING_TO_LOCATION;
+                w.flags.set(WindowFlag::scrollingToLocation);
             }
         }
     }
@@ -452,7 +456,7 @@ static constexpr float kWindowScrollLocations[][2] = {
             w.savedViewPos.y -= v->ViewHeight() / 4;
         }
 
-        if (Config::Get().general.ZoomToCursor && atCursor)
+        if (Config::Get().general.zoomToCursor && atCursor)
         {
             const auto mouseCoords = ContextGetCursorPositionScaled() - v->pos;
             const int32_t diffX = (mouseCoords.x - (zoomLevel.ApplyInversedTo(v->ViewWidth()) / 2));
@@ -476,27 +480,27 @@ static constexpr float kWindowScrollLocations[][2] = {
         // a window on top of the viewport.
         auto* windowMgr = Ui::GetWindowManager();
         windowMgr->BringToFront(w);
-        w.Invalidate();
+        w.invalidate();
     }
 
     /**
      * Splits a drawing of a window into regions that can be seen and are not hidden
      * by other opaque overlapping windows.
      */
-    void WindowDraw(RenderTarget& rt, WindowBase& w, int32_t left, int32_t top, int32_t right, int32_t bottom)
+    void WindowDraw(Drawing::RenderTarget& rt, WindowBase& w, int32_t left, int32_t top, int32_t right, int32_t bottom)
     {
         if (!w.isVisible)
             return;
 
         // Divide the draws up for only the visible regions of the window recursively
         auto itPos = WindowGetIterator(&w);
-        for (auto it = std::next(itPos); it != g_window_list.end(); it++)
+        for (auto it = std::next(itPos); it != gWindowList.end(); it++)
         {
             // Check if this window overlaps w
             auto topwindow = it->get();
-            if (topwindow->flags & WF_TRANSPARENT)
+            if (topwindow->flags.has(WindowFlag::transparent))
                 continue;
-            if (topwindow->flags & WF_DEAD)
+            if (topwindow->flags.has(WindowFlag::dead))
                 continue;
             if (topwindow->windowPos.x >= right || topwindow->windowPos.y >= bottom)
                 continue;
@@ -540,7 +544,8 @@ static constexpr float kWindowScrollLocations[][2] = {
     /**
      * Draws the given window and any other overlapping transparent windows.
      */
-    static void WindowDrawCore(RenderTarget& rt, WindowBase& w, int32_t left, int32_t top, int32_t right, int32_t bottom)
+    static void WindowDrawCore(
+        Drawing::RenderTarget& rt, WindowBase& w, int32_t left, int32_t top, int32_t right, int32_t bottom)
     {
         // Clamp region
         left = std::max<int32_t>(left, w.windowPos.x);
@@ -553,23 +558,25 @@ static constexpr float kWindowScrollLocations[][2] = {
             return;
 
         // Draw the window and any other overlapping transparent windows
-        for (auto it = WindowGetIterator(&w); it != g_window_list.end(); it++)
+        for (auto it = WindowGetIterator(&w); it != gWindowList.end(); it++)
         {
             auto* v = (*it).get();
-            if (v->flags & WF_DEAD)
+            if (v->flags.has(WindowFlag::dead))
                 continue;
-            if ((&w == v || (v->flags & WF_TRANSPARENT)) && v->isVisible)
+            if ((&w == v || v->flags.has(WindowFlag::transparent)) && v->isVisible)
             {
                 WindowDrawSingle(rt, *v, left, top, right, bottom);
             }
         }
     }
 
-    static void WindowDrawSingle(RenderTarget& rt, WindowBase& w, int32_t left, int32_t top, int32_t right, int32_t bottom)
+    static void WindowDrawSingle(
+        Drawing::RenderTarget& rt, WindowBase& w, int32_t left, int32_t top, int32_t right, int32_t bottom)
     {
         assert(rt.zoom_level == ZoomLevel{ 0 });
+
         // Copy render target so we can crop it
-        RenderTarget copy = rt;
+        Drawing::RenderTarget copy = rt;
 
         // Clamp left to 0
         int32_t overflow = left - copy.x;
@@ -615,34 +622,34 @@ static constexpr float kWindowScrollLocations[][2] = {
 
         // Invalidate modifies the window colours so first get the correct
         // colour before setting the global variables for the string painting
-        w.OnPrepareDraw();
+        w.onPrepareDraw();
 
         // Text colouring
         gCurrentWindowColours[0] = w.colours[0].colour;
         gCurrentWindowColours[1] = w.colours[1].colour;
         gCurrentWindowColours[2] = w.colours[2].colour;
 
-        w.OnDraw(copy);
+        w.onDraw(copy);
     }
 
     bool isToolActive(WindowClass cls)
     {
-        return gInputFlags.has(InputFlag::toolActive) && gCurrentToolWidget.window_classification == cls;
+        return gInputFlags.has(InputFlag::toolActive) && gCurrentToolWidget.windowClassification == cls;
     }
 
-    bool isToolActive(WindowClass cls, rct_windownumber number)
+    bool isToolActive(WindowClass cls, WindowNumber number)
     {
-        return isToolActive(cls) && gCurrentToolWidget.window_number == number;
+        return isToolActive(cls) && gCurrentToolWidget.windowNumber == number;
     }
 
     bool isToolActive(WindowClass cls, WidgetIndex widgetIndex)
     {
-        return isToolActive(cls) && gCurrentToolWidget.widget_index == widgetIndex;
+        return isToolActive(cls) && gCurrentToolWidget.widgetIndex == widgetIndex;
     }
 
-    bool isToolActive(WindowClass cls, WidgetIndex widgetIndex, rct_windownumber number)
+    bool isToolActive(WindowClass cls, WidgetIndex widgetIndex, WindowNumber number)
     {
-        return isToolActive(cls, widgetIndex) && gCurrentToolWidget.window_number == number;
+        return isToolActive(cls, widgetIndex) && gCurrentToolWidget.windowNumber == number;
     }
 
     bool isToolActive(const WindowBase& w, WidgetIndex widgetIndex)
@@ -662,8 +669,8 @@ static constexpr float kWindowScrollLocations[][2] = {
     {
         if (gInputFlags.has(InputFlag::toolActive))
         {
-            if (w.classification == gCurrentToolWidget.window_classification && w.number == gCurrentToolWidget.window_number
-                && widgetIndex == gCurrentToolWidget.widget_index)
+            if (w.classification == gCurrentToolWidget.windowClassification && w.number == gCurrentToolWidget.windowNumber
+                && widgetIndex == gCurrentToolWidget.widgetIndex)
             {
                 ToolCancel();
                 return true;
@@ -673,12 +680,12 @@ static constexpr float kWindowScrollLocations[][2] = {
         }
 
         gInputFlags.set(InputFlag::toolActive);
-        gInputFlags.unset(InputFlag::unk4);
-        gInputFlags.unset(InputFlag::unk6);
+        gInputFlags.unset(InputFlag::leftMousePressed);
+        gInputFlags.unset(InputFlag::allowRightMouseRemoval);
         gCurrentToolId = tool;
-        gCurrentToolWidget.window_classification = w.classification;
-        gCurrentToolWidget.window_number = w.number;
-        gCurrentToolWidget.widget_index = widgetIndex;
+        gCurrentToolWidget.windowClassification = w.classification;
+        gCurrentToolWidget.windowNumber = w.number;
+        gCurrentToolWidget.widgetIndex = widgetIndex;
         return false;
     }
 
@@ -692,26 +699,22 @@ static constexpr float kWindowScrollLocations[][2] = {
         {
             gInputFlags.unset(InputFlag::toolActive);
 
-            MapInvalidateSelectionRect();
-            MapInvalidateMapSelectionTiles();
-
             // Reset map selection
-            gMapSelectFlags = 0;
+            gMapSelectFlags.clearAll();
 
-            if (gCurrentToolWidget.widget_index != kWidgetIndexNull)
+            if (gCurrentToolWidget.widgetIndex != kWidgetIndexNull)
             {
                 auto* windowMgr = Ui::GetWindowManager();
 
                 // Invalidate tool widget
                 windowMgr->InvalidateWidgetByNumber(
-                    gCurrentToolWidget.window_classification, gCurrentToolWidget.window_number,
-                    gCurrentToolWidget.widget_index);
+                    gCurrentToolWidget.windowClassification, gCurrentToolWidget.windowNumber, gCurrentToolWidget.widgetIndex);
 
                 // Abort tool event
                 WindowBase* w = windowMgr->FindByNumber(
-                    gCurrentToolWidget.window_classification, gCurrentToolWidget.window_number);
+                    gCurrentToolWidget.windowClassification, gCurrentToolWidget.windowNumber);
                 if (w != nullptr)
-                    w->OnToolAbort(gCurrentToolWidget.widget_index);
+                    w->onToolAbort(gCurrentToolWidget.widgetIndex);
             }
         }
     }
@@ -726,32 +729,32 @@ static constexpr float kWindowScrollLocations[][2] = {
             return;
 
         auto* windowMgr = Ui::GetWindowManager();
-        WindowBase* titleWind = windowMgr->FindByClass(WindowClass::TitleMenu);
+        WindowBase* titleWind = windowMgr->FindByClass(WindowClass::titleMenu);
         if (titleWind != nullptr)
         {
             titleWind->windowPos.x = (width - titleWind->width) / 2;
             titleWind->windowPos.y = height - 182;
         }
 
-        WindowBase* versionWind = windowMgr->FindByClass(WindowClass::TitleVersion);
+        WindowBase* versionWind = windowMgr->FindByClass(WindowClass::titleVersion);
         if (versionWind != nullptr)
             versionWind->windowPos.y = height - 30;
 
-        WindowBase* exitWind = windowMgr->FindByClass(WindowClass::TitleExit);
+        WindowBase* exitWind = windowMgr->FindByClass(WindowClass::titleExit);
         if (exitWind != nullptr)
         {
             exitWind->windowPos.x = width - 40;
             exitWind->windowPos.y = height - 64;
         }
 
-        WindowBase* optionsWind = windowMgr->FindByClass(WindowClass::TitleOptions);
+        WindowBase* optionsWind = windowMgr->FindByClass(WindowClass::titleOptions);
         if (optionsWind != nullptr)
         {
             optionsWind->windowPos.x = width - 80;
         }
 
         // Keep options window centred after a resize
-        WindowBase* optionsWindow = windowMgr->FindByClass(WindowClass::Options);
+        WindowBase* optionsWindow = windowMgr->FindByClass(WindowClass::options);
         if (optionsWindow != nullptr)
         {
             optionsWindow->windowPos.x = (ContextGetWidth() - optionsWindow->width) / 2;
@@ -759,7 +762,7 @@ static constexpr float kWindowScrollLocations[][2] = {
         }
 
         // Keep progress bar window centred after a resize
-        WindowBase* ProgressWindow = windowMgr->FindByClass(WindowClass::ProgressWindow);
+        WindowBase* ProgressWindow = windowMgr->FindByClass(WindowClass::progressWindow);
         if (ProgressWindow != nullptr)
         {
             ProgressWindow->windowPos.x = (ContextGetWidth() - ProgressWindow->width) / 2;
@@ -791,13 +794,13 @@ static constexpr float kWindowScrollLocations[][2] = {
 
         auto* windowMgr = Ui::GetWindowManager();
 
-        WindowBase* topWind = windowMgr->FindByClass(WindowClass::TopToolbar);
+        WindowBase* topWind = windowMgr->FindByClass(WindowClass::topToolbar);
         if (topWind != nullptr)
         {
             topWind->width = std::max(640, width);
         }
 
-        WindowBase* bottomWind = windowMgr->FindByClass(WindowClass::BottomToolbar);
+        WindowBase* bottomWind = windowMgr->FindByClass(WindowClass::bottomToolbar);
         if (bottomWind != nullptr)
         {
             bottomWind->windowPos.y = height - 32;
@@ -812,16 +815,16 @@ static constexpr float kWindowScrollLocations[][2] = {
     void WindowUpdateViewportRideMusic()
     {
         RideAudio::ClearAllViewportInstances();
-        g_music_tracking_viewport = nullptr;
+        gMusicTrackingViewport = nullptr;
 
-        for (auto it = g_window_list.rbegin(); it != g_window_list.rend(); it++)
+        for (auto it = gWindowList.rbegin(); it != gWindowList.rend(); it++)
         {
             auto w = it->get();
             auto viewport = w->viewport;
             if (viewport == nullptr || !(viewport->flags & VIEWPORT_FLAG_SOUND_ON))
                 continue;
 
-            g_music_tracking_viewport = viewport;
+            gMusicTrackingViewport = viewport;
             gWindowAudioExclusive = w;
 
             if (viewport->zoom <= ZoomLevel{ 0 })
@@ -841,7 +844,7 @@ static constexpr float kWindowScrollLocations[][2] = {
     void TextinputCancel()
     {
         auto* windowMgr = Ui::GetWindowManager();
-        windowMgr->CloseByClass(WindowClass::Textinput);
+        windowMgr->CloseByClass(WindowClass::textinput);
     }
 
     /**
@@ -852,11 +855,11 @@ static constexpr float kWindowScrollLocations[][2] = {
      * right (dx)
      * bottom (bp)
      */
-    void WindowDrawAll(RenderTarget& rt, int32_t left, int32_t top, int32_t right, int32_t bottom)
+    void WindowDrawAll(Drawing::RenderTarget& rt, int32_t left, int32_t top, int32_t right, int32_t bottom)
     {
         auto windowRT = rt.Crop({ left, top }, { right - left, bottom - top });
         WindowVisitEach([&windowRT, left, top, right, bottom](WindowBase* w) {
-            if (w->flags & WF_TRANSPARENT)
+            if (w->flags.has(WindowFlag::transparent))
                 return;
             if (right <= w->windowPos.x || bottom <= w->windowPos.y)
                 return;
@@ -869,21 +872,21 @@ static constexpr float kWindowScrollLocations[][2] = {
     void WindowInitAll()
     {
         auto* windowMgr = Ui::GetWindowManager();
-        windowMgr->CloseAllExceptFlags(0);
+        windowMgr->CloseAllExceptFlags({});
     }
 
     void WindowFollowSprite(WindowBase& w, EntityId spriteIndex)
     {
         if (spriteIndex.ToUnderlying() < kMaxEntities || spriteIndex.IsNull())
         {
-            w.viewport_smart_follow_sprite = spriteIndex;
+            w.viewportSmartFollowSprite = spriteIndex;
         }
     }
 
     void WindowUnfollowSprite(WindowBase& w)
     {
-        w.viewport_smart_follow_sprite = EntityId::GetNull();
-        w.viewport_target_sprite = EntityId::GetNull();
+        w.viewportSmartFollowSprite = EntityId::GetNull();
+        w.viewportTargetSprite = EntityId::GetNull();
     }
 
     Viewport* WindowGetViewport(WindowBase* w)
