@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2025 OpenRCT2 developers
+ * Copyright (c) 2014-2026 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -7,7 +7,7 @@
  * OpenRCT2 is licensed under the GNU General Public License version 3.
  *****************************************************************************/
 
-#if defined(__unix__) && !defined(__ANDROID__) && !defined(__APPLE__)
+#if (defined(__unix__) || defined(__HAIKU__)) && !defined(__ANDROID__) && !defined(__APPLE__) && !defined(__EMSCRIPTEN__)
 
     #include "../Diagnostic.h"
 
@@ -38,6 +38,10 @@
     #include "../localisation/Language.h"
     #include "Platform.h"
 
+    #ifdef __HAIKU__
+        #include <image.h>
+    #endif
+
 namespace OpenRCT2::Platform
 {
     // EnvLangGuard allows us to temporarily set the user's locale
@@ -154,6 +158,12 @@ namespace OpenRCT2::Platform
             "/usr/local/share/openrct2",
             "/var/lib/openrct2",
             "/usr/share/openrct2",
+    #ifdef __HAIKU__
+            "/boot/system/data/openrct2",
+            "/boot/home/config/data/openrct2",
+            "/boot/system/non-packaged/data/openrct2",
+            "/boot/home/config/non-packaged/data/openrct2",
+    #endif
         };
         // clang-format on
         for (const auto& prefix : prefixes)
@@ -180,6 +190,18 @@ namespace OpenRCT2::Platform
         {
             LOG_FATAL("failed to read /proc/self/exe");
         }
+    #elif defined(__HAIKU__)
+        image_info info;
+        int32 cookie = 0;
+
+        while (get_next_image_info(B_CURRENT_TEAM, &cookie, &info) >= B_OK)
+        {
+            if (info.type == B_APP_IMAGE)
+            {
+                strlcpy(exePath, info.name, sizeof(exePath));
+                break;
+            }
+        }
     #elif defined(__FreeBSD__) || defined(__NetBSD__)
         #if defined(__FreeBSD__)
         const int32_t mib[] = {
@@ -201,7 +223,7 @@ namespace OpenRCT2::Platform
         {
             LOG_FATAL("failed to get process path");
         }
-    #elif defined(__OpenBSD__) || defined(__EMSCRIPTEN__)
+    #elif defined(__OpenBSD__)
         // There is no way to get the path name of a running executable.
         // If you are not using the port or package, you may have to change this line!
         strlcpy(exePath, "/usr/local/bin/", sizeof(exePath));
@@ -320,65 +342,52 @@ namespace OpenRCT2::Platform
         return MeasurementFormat::Metric;
     }
 
-    std::string GetSteamPath()
+    SteamPaths GetSteamPaths()
     {
+        SteamPaths ret = {};
+        ret.nativeFolder = "steamapps/common";
+        ret.downloadDepotFolder = "ubuntu12_32/steamapps/content";
+        ret.manifests = "steamapps";
+
         const char* steamRoot = getenv("STEAMROOT");
         if (steamRoot != nullptr)
         {
-            return Path::Combine(steamRoot, u8"ubuntu12_32/steamapps/content");
+            ret.roots.emplace_back(steamRoot);
         }
 
         const char* localSharePath = getenv("XDG_DATA_HOME");
         if (localSharePath != nullptr)
         {
-            auto steamPath = Path::Combine(localSharePath, u8"Steam/ubuntu12_32/steamapps/content");
-            if (Path::DirectoryExists(steamPath))
+            auto xdgDataHomeSteamPath = Path::Combine(localSharePath, u8"Steam");
+            if (Path::DirectoryExists(xdgDataHomeSteamPath))
             {
-                return steamPath;
+                ret.roots.emplace_back(xdgDataHomeSteamPath);
             }
         }
 
         const char* homeDir = getpwuid(getuid())->pw_dir;
-        if (homeDir == nullptr)
+        if (homeDir != nullptr)
         {
-            return {};
+            auto localShareSteamPath = Path::Combine(homeDir, u8".local/share/Steam");
+            if (Path::DirectoryExists(localShareSteamPath))
+            {
+                ret.roots.emplace_back(localShareSteamPath);
+            }
+
+            auto oldSteamPath = Path::Combine(homeDir, u8".steam/steam");
+            if (Path::DirectoryExists(oldSteamPath))
+            {
+                ret.roots.emplace_back(oldSteamPath);
+            }
+
+            auto snapLocalShareSteamPath = Path::Combine(homeDir, u8"snap/steam/common/.local/share/Steam");
+            if (Path::DirectoryExists(snapLocalShareSteamPath))
+            {
+                ret.roots.emplace_back(snapLocalShareSteamPath);
+            }
         }
 
-        // Prefer new path for Steam, which is the default when using with Proton
-        auto steamPath = Path::Combine(homeDir, u8".local/share/Steam/steamapps/common");
-        if (Path::DirectoryExists(steamPath))
-        {
-            return steamPath;
-        }
-
-        // Fallback paths
-        steamPath = Path::Combine(homeDir, u8".local/share/Steam/ubuntu12_32/steamapps/content");
-        if (Path::DirectoryExists(steamPath))
-        {
-            return steamPath;
-        }
-
-        steamPath = Path::Combine(homeDir, u8".steam/steam/ubuntu12_32/steamapps/content");
-        if (Path::DirectoryExists(steamPath))
-        {
-            return steamPath;
-        }
-        return {};
-    }
-
-    u8string GetRCT1SteamDir()
-    {
-        return u8"Rollercoaster Tycoon Deluxe";
-    }
-
-    u8string GetRCT2SteamDir()
-    {
-        return u8"Rollercoaster Tycoon 2";
-    }
-
-    u8string GetRCTClassicSteamDir()
-    {
-        return u8"RollerCoaster Tycoon Classic";
+        return ret;
     }
 
     std::vector<std::string_view> GetSearchablePathsRCT1()
