@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2025 OpenRCT2 developers
+ * Copyright (c) 2014-2026 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -102,7 +102,7 @@ namespace OpenRCT2::Scripting
 
     Vehicle* ScVehicle::GetVehicle() const
     {
-        return ::getGameState().entities.GetEntity<Vehicle>(_id);
+        return getGameState().entities.GetEntity<Vehicle>(_id);
     }
 
     ObjectEntryIndex ScVehicle::rideObject_get() const
